/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Checksum checking logic for Srm/Url copy - utilities
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: ChecksumCheckerUtils.cpp,v 1.4 2009/10/26 16:32:20 molnarzs Exp $
 *  Release: $Name:  $
 */
#include "ChecksumCheckerUtils.h"
#include "logger-utility.h"

#include <cstdio>
#include <assert.h>

namespace glite {
namespace data {
namespace transfer {
namespace urlcopy {

namespace ChecksumCheckerUtils {

namespace {
/**
 * Check if the algorithm name is a standard one or not
 *
 * @param alg The algorithm name
 * @return tre if the name is standard
 */
bool _IsStandardAlgorithmName(const std::string& alg);

/**
 * Convert a non-standard algorithm name into a standard one. This function collects the explored
 * algorithm name differences in the different systems, and puts them under common denominator.
 *
 * @param alg The algorithm name
 * @return the standardized name. If the name is unknown or standard, return it without change.
 */
std::string _ConvertToStandardAlgorithmName(const std::string& alg);
} // unnamed namespace

File::File() :
    algorithm(NULL),
    value(NULL),
    name(NULL),
    turl(NULL),
    isSrmLsProvidedChecksum(false),
    isSurl(true)
{
    // EMPTY
}

FilePair::FilePair() :
    compare(false),
    userAlg(NULL),
    userVal(NULL),
    isUserProvidedChecksum(false),
    useCase(e_noChecksumComparison)
{
    // EMPTY
}

FilePair::~FilePair()
{
    // EMPTY
}

} // namespace ChecksumCheckerUtils

} // namespace urlcopy
} // namespace transfer
} // namespace data
} // namespace glite
