/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Checksum retrieval with gridFTP
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: ChecksumGetter_gridFTP.h,v 1.2 2009/08/04 17:49:05 molnarzs Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_URL_CHECKSUM_GETTER_GRIDFTP_H_
#define GLITE_DATA_TRANSFER_URL_COPY_URL_CHECKSUM_GETTER_GRIDFTP_H_

#include "IChecksumGetter.h"

namespace glite {
namespace data {
namespace transfer {
namespace urlcopy {

/**
 * Obtain a checksum by using gridFTP.
 */
class ChecksumGetter_gridFTP: public IChecksumGetter
{
public:
    virtual ~ChecksumGetter_gridFTP();

    /** See parent */
    virtual void getChecksumFromGridFTP(
        ChecksumCheckerUtils::FilePair& filePair,
        ChecksumCheckerUtils::File& file,
        const unsigned int timeout,
        RefreshTimeUpdater::IUpdateRefreshTime* updater,
        UrlCopyError::Category& c,
        std::string& m);

private:
    /**
     * Get the checksum for a (source or destination) file - execute a physical gridftp call.
     *
     * @param filePair The source/destination pair (for the user checksum info)
     * @param file Source or destination of the pair
     * @param timeout Timeout for the operation
     * @param updater The RefreshTimeUpdater that should be used by the under-laying operation
     * @param c Output - in case of error, the error category gets here
     * @param m Output - in case of error, the error message gets here
     */
    void _executeGridFTP(
        ChecksumCheckerUtils::FilePair& filePair,
        ChecksumCheckerUtils::File& file,
        const unsigned int timeout,
        RefreshTimeUpdater::IUpdateRefreshTime* updater,
        UrlCopyError::Category& c,
        std::string& m);

    /**
     * Select which checksum algorithm is used in case of grifFTP query. The order is:
     *
     * 1. Source algorithm name (if srmLs returned checksum).
     * 2. The algorithm given by teh user
     * 3. The default algorithm
     *
     * Use this method only after all the corresponding fields of the stat are
     * set properly, otherwise the method will come up with false decision.
     *
     * @param filePair The source/destination pair
     * @param file Source or destination of the pair
     */
    static const char* _SelectChecksumAlgorithmForGridFTP(
        const ChecksumCheckerUtils::FilePair& filePair,
        const ChecksumCheckerUtils::File& file);
};

} // namespace urlcopy
} // namespace transfer
} // namespace data
} // namespace glite

#endif // GLITE_DATA_TRANSFER_URL_COPY_URL_CHECKSUM_GETTER_GRIDFTP_H_
