/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: ChecksumCheckerUtils.cpp,v 1.4 2009/10/26 16:32:20 molnarzs Exp $
 *  Release: $Name:  $
 */
#include "FileRemover_gridFTP.h"
#include "gridftp-utility.h"
#include "logger-utility.h"

namespace glite {
namespace data {
namespace transfer {
namespace urlcopy {

void FileRemover_gridFTP::RemoveFile(
    const int timeout,
    RefreshTimeUpdater::IUpdateRefreshTime* rtu, 
    const std::string& fileName)
{
    INFO_LOG(FileRemover_gridFTP) << "Removing file [" << fileName << "] with grifFTP.";
    UrlCopyError::Category c = UrlCopyError::ERROR_GENERAL_FAILURE;
    std::string msg;
    gridftp_rmfile(fileName, timeout, c, msg, rtu);

    if (c == UrlCopyError::SUCCESS) {
        INFO_LOG(FileRemover_gridFTP) << "File [" << fileName << "] removed"; 
    } else {
        INFO_LOG(FileRemover_gridFTP) << "File [" << fileName << "] cannot be removed:" 
            << c << "(" << msg << ")"; 
    }
}
    
} // namespace urlcopy
} // namespace transfer
} // namespace data
} // namespace glite

