/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: FileType class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: FileType.cpp,v 1.3 2008/10/20 09:03:05 ptedesco Exp $
 *  Release: $Name:  $
 */

#include "FileType.h"
#include <glite/data/agents/Url.h>

using glite::data::agents::Url;

namespace {
const char * const SRM_SCHEMA    = "srm";
const char * const SFN_SCHEMA    = "sfn"; 
const char * const GSIFTP_SCHEMA = "gsiftp";
}

#define EVAL_CASE(name) case name: return #name;

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {
    
/*
 * get
 *
 * Get the type of an URL
 */
FileType::Value FileType::get(const std::string& str) throw() {
    FileType::Value type = FileType::UNDEF;
    
    // Create an Url Object
    Url url(str);
    if(false == url.isGood()){
        // Not a url, consider it a local file
        type = FileType::LOCAL;
    } else {
        // Check the schema
        if(url.schema == SRM_SCHEMA){
            type = FileType::SURL;
        } else if(url.schema == SFN_SCHEMA){
            type = FileType::SFN;
        } else if(url.schema == GSIFTP_SCHEMA){
            type = FileType::TURL;
        } else {
            type = FileType::URL;
        }
    }
    return type;
}

/*
 * toString
 *
 * Get the string representation of a file type
 */
const char * FileType::toString(Value v) throw(){
    switch(v){
    EVAL_CASE(LOCAL)
    EVAL_CASE(SURL)
    EVAL_CASE(TURL)
    EVAL_CASE(SFN)
    EVAL_CASE(URL)
    default: return "";
    }
}

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

namespace std{
std::ostream& operator << (std::ostream& stream,glite::data::transfer::urlcopy::FileType::Value value){
    stream << glite::data::transfer::urlcopy::FileType::toString(value);
    return stream;
}
} // namespace std
