/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: FileType class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: FileType.h,v 1.3 2008/10/20 09:03:05 ptedesco Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_FILE_TYPE_H_
#define GLITE_DATA_TRANSFER_URL_COPY_FILE_TYPE_H_

#include <string>
#include <ostream>

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

/**
 * The Mmap class is an helper for handling memory mapped files
 */
struct FileType{
public:

    typedef enum {
        UNDEF = 0,  // Undefined
        LOCAL,      // local file system, e.g. /tmp/test.txt
        SURL,       // SRM Surl, e.g. httpg://srm.cern.ch/castor/cern.ch/test.txt
        TURL,       // SRM Turl, e.g. gsiftp://srm.cern.ch/castor/cern.ch/test.txt
        SFN,        // SRM SFN, e.g. sfn:/castor/cern.ch/test.txt
        URL         // Any other URLs, e,g, file:///tmp/test.txt https://srm.cern.ch/castor/cern.ch/test.txt
    } Value;

    /**
     * Get the type of an url
     */
    static Value get(const std::string& url) throw();
    
    /**
     * Get the string representation of a file type
     */
    static const char * toString(Value v) throw();
};

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

namespace std{
std::ostream& operator << (std::ostream& stream,glite::data::transfer::urlcopy::FileType::Value value);
}

#endif //GLITE_DATA_TRANSFER_URL_COPY_FILE_TYPE_H_
