/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: gridftp helper methods 
 *   refactored from previous transfer-url-copy (Peter Kunszt) and lcg_util 
 *   (Jean-Philippe Baud)
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: GridFtpPatterns.h,v 1.2 2008/10/20 15:19:46 ptedesco Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_GRIDFTP_PATTERNS_H_
#define GLITE_DATA_TRANSFER_URL_COPY_GRIDFTP_PATTERNS_H_

#include <string>
#include <map>
#include <glite/data/agents/extra/XmlPatternsList.h>

#include <glite/data/transfer/urlcopy/UrlCopyError.h>

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

/**
 * GridFtpPatterns
 * wrapper for XmlPatternsList class
 */
class GridFtpPatterns{
public:
    /**
     * singleton instance
     */
    static GridFtpPatterns& instance();
    
    /**
     * translateGridFtpError 
     * translate a gridftp error message into an UrlCopyError category and scope
     * @param msg [IN] the error message
     * @param category [OUT] the error category (GRIDFTP if no better match is 
     * found) 
     * @param scope [OUT] the error scope (S_TRANSFER if no better match is 
     * found)
     */
    void translateGridFtpError(
        const std::string&      msg,
        UrlCopyError::Category& category,
        UrlCopyError::Scope&    scope);
    
    /**
     * categoryFromMessage
     * translate a gridftp error message returning only the corresponding category
     * @param msg [IN] the error message
     * @return the error category (GRIDFTP if no better match is found)
     */
    UrlCopyError::Category categoryFromMessage(
        const std::string& msg);

protected:
    
    /**
     * getMatch
     * get the match object corresponding to msg
     * @param msg [IN] the error message
     * @param category [OUT] the error category (GRIDFTP if no better match is 
     * found) 
     * @return PatternMatch if found, null otherwise
     */
    const glite::data::agents::XmlPatternsList::PatternMatch * getMatch(
        const std::string&      msg,
        UrlCopyError::Category& category);

    /**
     * constructor
     */
    GridFtpPatterns();
    
    /**
     * destructor
     */
    ~GridFtpPatterns();
    
    // XmlPatternsList object
    glite::data::agents::XmlPatternsList m_patterns;
    // map string->error category
    typedef std::map <std::string,UrlCopyError::Category> CategoryMap;
    CategoryMap m_categories;
    // map string->error scope
    typedef std::map <std::string,UrlCopyError::Scope> ScopeMap;
    ScopeMap m_scopes;
};

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif // GLITE_DATA_TRANSFER_URL_COPY_GRIDFTP_PATTERNS_H_

