/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Checksum checking logic for Srm/Url copy
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: IChecksumGetter.h,v 1.2 2009/08/04 17:49:05 molnarzs Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_URL_ICHECKSUMGETTER_H_
#define GLITE_DATA_TRANSFER_URL_COPY_URL_ICHECKSUMGETTER_H_

#include "RefreshTimeUpdater.h"
#include "ChecksumCheckerUtils.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

/**
 * Interface for the checksum information retrieving logic.
 */
struct IChecksumGetter
{
	virtual ~IChecksumGetter() { /* EMPTY */ }

    /**
     * Get the checksum for a (source or destination) file, and fill in the under-laying stat with
     * the info.
     *
     * @param filePair The source/destination pair (for the user checksum info)
     * @param file Source or destination of the pair
     * @param timeout Timeout for the operation
     * @param updater The RefreshTimeUpdater that should be used by the under-laying operation
     * @param c Output - in case of error, the error category gets here
     * @param m Output - in case of error, the error message gets here
     */
	virtual void getChecksumFromGridFTP(
		ChecksumCheckerUtils::FilePair& filePair,
		ChecksumCheckerUtils::File& file,
		const unsigned int timeout,
		RefreshTimeUpdater::IUpdateRefreshTime* updater,
		UrlCopyError::Category& c,
		std::string& m) = 0;
};

} // namespace urlcopy
} // namespace transfer
} // namespace data
} // namespace glite

#endif // GLITE_DATA_TRANSFER_URL_COPY_URL_ICHECKSUMGETTER_H_
