/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Instrument representation
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: Instrument.cpp,v 1.1 2009/10/26 16:32:20 molnarzs Exp $
 *  Release: $Name:  $
 */
#include "Instrument.h"
#include "logger-utility.h"

#include <glite/data/agents/AgentExceptions.h>

#include <boost/tokenizer.hpp>
#include <algorithm>
#include <assert.h>

namespace glite {
namespace data {
namespace transfer {
namespace urlcopy {

Instrument& Instrument::Instance()
{
    static Instrument instance;
    return instance;
}

void Instrument::set(const std::string& arg)
{
    boost::tokenizer<> tokenizer(arg);       
    std::vector<std::string> tok(tokenizer.begin(), tokenizer.end());
    assert(tok.size());

    if (tok[0] == "srcSrmlsNoChecksum") {
        DEBUG_LOG(Instrument) << "srcSrmlsNoChecksum";
        srcSrmlsNoChecksum.reset(new bool);
        return;
    }

    if (tok[0] == "dstSrmlsNoChecksum") {
        DEBUG_LOG(Instrument) << "dstSrmlsNoChecksum";
        dstSrmlsNoChecksum.reset(new bool);
        return;
    }

    if (tok[0] == "srcSrmlsYesChecksum") {
        assert(tok.size() == 3);
        srcSrmlsYesChecksum.reset(new Checksum(tok[1], tok[2]));
        DEBUG_LOG(Instrument) << "srcSrmlsYesChecksum " << srcSrmlsYesChecksum;
        return;
    }

    if (tok[0] == "dstSrmlsYesChecksum") {
        assert(tok.size() == 3);
        dstSrmlsYesChecksum.reset(new Checksum(tok[1], tok[2]));
        DEBUG_LOG(Instrument) << "dstSrmlsYesChecksum " << dstSrmlsYesChecksum;
        return;
    }

    if (tok[0] == "srcChecksumNotAvailable") {
        DEBUG_LOG(Instrument) << "srcChecksumNotAvailable";
        srcChecksumNotAvailable.reset(new bool);
        return;
    }

    if (tok[0] == "dstChecksumNotAvailable") {
        DEBUG_LOG(Instrument) << "dstChecksumNotAvailable";
        dstChecksumNotAvailable.reset(new bool);
        return;
    }

    if (tok[0] == "dstForceChecksum") {
        assert(tok.size() == 3);
        dstForceChecksum.reset(new Checksum(tok[1], tok[2]));
        DEBUG_LOG(Instrument) << "dstForceChecksum " << dstForceChecksum;
        return;
    }

    if (tok[0] == "srcForceChecksum") {
        assert(tok.size() == 3);
        srcForceChecksum.reset(new Checksum(tok[1], tok[2]));
        DEBUG_LOG(Instrument) << "srcForceChecksum " << srcForceChecksum;
        return;
    }

    ERROR_LOG(Instrument) << "Wrong instrumenting string '" << arg << "'";
    throw glite::data::agents::LogicError("Instrumenting error");
}

} // namespace urlcopy
} // namespace transfer
} // namespace data
} // namespace glite
