/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Mmap class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Mmap.h,v 1.3 2008/10/20 09:03:05 ptedesco Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_MMAP_H_
#define GLITE_DATA_TRANSFER_URL_COPY_MMAP_H_

#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

/**
 * The Mmap class is an helper for handling memory mapped files
 */
class Mmap : boost::noncopyable {
public:

    /**
     * Construct
     */
    Mmap(const std::string& file_name);

    /**
     * Destructor
     */
    ~Mmap();

    /**
     * create a new File
     */
    void * create(size_t size, bool shared = true) /*throw (LogicError, RuntimeError)*/;

    /**
     * open an existing File
     */
    void * open(size_t& size, bool read_only, bool shared = true) /*throw (LogicError, RuntimeError)*/;

    /**
     * close the file
     */
    void close(bool nothrow = false) /*throw (LogicError, RuntimeError)*/;

    /**
     * unlink the file
     */
    void unlink(bool nothrow = false) /*throw (LogicError, RuntimeError)*/;

    /**
     * Return the Mmap buffer
     */
    void * buffer()  /*throw (LogicError)*/;

    /**
     * Return the buffer size
     */
    unsigned long size()  /*throw (LogicError)*/;

private:

    /**
     * Default Constructor. Not Implemented
     */
    Mmap();

private:
    /**
     * The file name
     */
    std::string m_fileName;
    /**
     * The pointer to the file buffer
     */
    void * m_buffer;
    /**
     * The buffer size
     */
    size_t m_size;
};

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_URL_COPY_MMAP_H_
