/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: gridftp helper methods 
 *   refactored from previous transfer-url-copy (Peter Kunszt) and lcg_util 
 *   (Jean-Philippe Baud)
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>, Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: PerfMarker.h,v 1.1 2008/02/20 14:33:36 ptedesco Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_PERFMARKER_H_
#define GLITE_DATA_TRANSFER_URL_COPY_PERFMARKER_H_

#include <glite/data/agents/glite-types.h>
#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

/**
 * PerfMarker Class
 */ 
struct PerfMarker {
    /**
     * Timestamp of last marker
     */
    struct timespec ts;
    /**
     * Number of markers received
     */
    int markers;
    /**
     * Number of bytes transferred
     */
    glite::data::agents::longlong transferred_bytes;
    /**
     * Average throughput
     */
    float avg_throughput;
    /**
     * Instant throughput
     */
    float instant_throughput;
} ;

/**
 * User specific Callback. Return 1 to cancel the operation, 0 to continue
 */ 
typedef int (* gridftpcopy_callback_t) (
    void *       user_arg,
    PerfMarker&  perf
) /*throw()*/;

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif // GLITE_DATA_TRANSFER_URL_COPY_PERFMARKER_H_

