/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: RefreshTimeUpdater utility
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: RefreshTimeUpdater.h,v 1.3 2008/10/15 07:21:15 ptedesco Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_REFRESH_TIME_UPDATER_H_
#define GLITE_DATA_TRANSFER_URL_COPY_REFRESH_TIME_UPDATER_H_

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

/**
 * RefreshTimeUpdater
 * RAII utility to update the stat last refresh time
 */
class RefreshTimeUpdater{
public:
    /**
     * IUpdateRefreshTime
     * @stereotype interface
     */
    class IUpdateRefreshTime{
    public:
        /**
         * UpdateRefreshTime
         */
        virtual void UpdateRefreshTime() = 0;
    protected:
        virtual ~IUpdateRefreshTime(){} // silence gcc warning
    };
    /**
     * constructor
     */
    RefreshTimeUpdater(IUpdateRefreshTime* update);
    
    /**
     * destructor
     */
    ~RefreshTimeUpdater();
    
private:
    // default constructor not implemented
    RefreshTimeUpdater();
    // the object to update
    IUpdateRefreshTime* m_update;
};

} // namespace urlcopy
} // namespace transfer
} // namespace data
} // namespace glite

#endif // GLITE_DATA_TRANSFER_URL_COPY_REFRESH_TIME_UPDATER_H_
