/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: SrmCopyStat structure
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: SrmCopyStat.h,v 1.9 2009/07/30 19:32:55 molnarzs Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_SRM_COPY_STAT_H_
#define GLITE_DATA_TRANSFER_URL_COPY_SRM_COPY_STAT_H_

#include <glite/data/agents/glite-types.h>
#include "StatCommon.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

/**
 * SRMCopy Stat Version
 */
#define SRMCOPY_STAT_EXTENSION    0x00000002

/**
 * SRMCopy Stat ID
 */
#define SRMCOPY_STAT_ID         0xbbbbbbbb

/**
 * UrlCopy File Transfer Stat Structure
 */
struct SrmCopy_FileStat {
    // File Request Status
    unsigned int                    mm_status;
    // Source File
    char                            mm_src_name [TRANSFER_STAT_URL_LEN];
    // Destination File
    char                            mm_dest_name[TRANSFER_STAT_URL_LEN];
    // Destination file existed before the transfer
    int                             mm_dest_exists;
    // Source File size (used for comparison)
    glite::data::agents::longlong   mm_src_size;
    // File size
    glite::data::agents::longlong   mm_size;
    // Error
    ErrorStat                       mm_error;
    // Start and completion time
    time_t                          mm_start_time;
    time_t                          mm_done_time;
    // Checksum data
    // added with stat version 3.5.0
    // flag specifying if checksums should be compared
    int                             mm_compare_checksum;
    // checksum algorithm specified by the user
    char                            mm_checksum_user_algorithm[CHECKSUM_ALGORITHM_LEN];
    // checksum value specified by the user
    char                            mm_checksum_user_value[CHECKSUM_VALUE_LEN];
    // src checksum algorithm (got with srmLs or gridftp)
    char         mm_src_checksum_algorithm[CHECKSUM_ALGORITHM_LEN];
    // src checksum value (got with srmLs or gridftp)
    char         mm_src_checksum_value[CHECKSUM_VALUE_LEN];
    // dst checksum algorithm (got with srmLs or gridftp)
    char         mm_dst_checksum_algorithm[CHECKSUM_ALGORITHM_LEN];
    // dst checksum value (got with srmLs or gridftp)
    char         mm_dst_checksum_value[CHECKSUM_VALUE_LEN];
    // src TURL
    char         mm_src_tx_name     [TRANSFER_STAT_URL_LEN];
    // dst TURL
    char         mm_dst_tx_name     [TRANSFER_STAT_URL_LEN];
};

/**
 * SrmCopy Request Stat Structure
 */
struct SrmCopy_Stat {
    // Request Status
    unsigned int mm_status;
    char         mm_src_srm_endpoint [TRANSFER_STAT_URL_LEN];
    char         mm_src_srm_version  [TRANSFER_STAT_VERSION_LEN];
    char         mm_dest_srm_endpoint[TRANSFER_STAT_URL_LEN];
    char         mm_dest_srm_version [TRANSFER_STAT_VERSION_LEN];
    char         mm_token            [TRANSFER_STAT_TOKEN_LEN];
    time_t       mm_src_prep_start_time;
    time_t       mm_src_prep_done_time;
    time_t       mm_dest_prep_start_time;
    time_t       mm_dest_prep_done_time;
    time_t       mm_start_time;
    time_t       mm_done_time;
    time_t       mm_final_start_time;
    time_t       mm_final_done_time;
    // SrmCopy properties
    int          mm_push_mode;
    // Error
    ErrorStat    mm_error;
    // Configuration
    int          mm_http_timeout;
    int          mm_copy_timeout;
    int          mm_refresh_timeout;
    double       mm_tx_to_per_mb;
};

/**
 * SrmCopy Stat Structure
 */
struct SrmCopyStat {
    // Transfer Common properties
    TransferStat     mm_common;
    // SrmCopy
    SrmCopy_Stat     mm_srmcopy;
    // File
    unsigned int     mm_num_files;
    SrmCopy_FileStat mm_files[0];
};

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_URL_COPY_SRM_COPY_STAT_H_
