/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Checksum checking logic for Srm/Url copy
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: SrmCopyUtils.cpp,v 1.1 2009/07/30 19:32:55 molnarzs Exp $
 *  Release: $Name:  $
 */
#include "SrmCopyUtils.h"
#include "logger-utility.h"
#include "stat-utility.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

namespace SrmCopyUtils {

void SetFileError(
	SrmCopy_FileStat& file,
	UrlCopyError::Scope s,
	UrlCopyError::Phase p,
	UrlCopyError::Category c,
	const std::string& m)
{
	file.mm_status =
		c == UrlCopyError::ERROR_ABORTED ? UrlCopyStatus::ABORTED : UrlCopyStatus::FAILED;

	file.mm_error.mm_scope    = s;
	file.mm_error.mm_phase    = p;
	file.mm_error.mm_category = c;
	copy_message(file.mm_error.mm_message, m.c_str());
	error() << "file '" << file.mm_src_name << "' failed during " << UrlCopyError::phaseToString(p) << " phase. Error [" << UrlCopyError::categoryToString(c) << "]: " << m;
}

} // namespace SrmCopyUtils

} // namespace urlcopy
} // namespace transfer
} // namespace data
} // namespace glite
