/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Call SRM Methods
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: SrmMethodCaller.h,v 1.2 2008/11/20 15:35:34 ptedesco Exp $
 *  Release: $Name:  $
 *
 */

#ifndef GLITE_DATA_TRANSFER_URL_COPY_SRMMETHODCALLER_H_
#define GLITE_DATA_TRANSFER_URL_COPY_SRMMETHODCALLER_H_
 
#include <glite/data/transfer/urlcopy/UrlCopyError.h>
#include <glite/data/transfer/urlcopy/UrlCopyStatus.h>
#include <glite/data/agents/AgentExceptions.h>
#include <glite/data/srm/util/types.h>
#include <glite/data/srm/util/Context.h>
#include <glite/data/srm/util/details/SynchRequest.h>
#include <glite/data/srm/util/details/AsynchRequest.h>

#include "RefreshTimeUpdater.h"

#include <boost/utility.hpp>
#include <boost/shared_ptr.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

class ContextLogInfo{
public:
    static std::string user_tag;
    static std::string tx_id;
private:
    ContextLogInfo();
};    
    
class SrmMethodCaller{
public:
    
    /**
     * Constructor
     */
    explicit SrmMethodCaller(
        RefreshTimeUpdater::IUpdateRefreshTime * updateRefreshTime);
    
    /**
     * Destructor
     */
    ~SrmMethodCaller();
    
    /**
     * Create SRM Context object
     * @param endpoint [IN] endpoint address
     * @param version [IN] endpoint version
     * @param http_timeout [IN] http timeout in seconds
     * @return pointer to SRM context
     */
    glite::data::srm::util::Context::Ptr createSrmCtx(
        const std::string&  endpoint, 
        const std::string&  version, 
        int                 http_timeout) throw();

    /**
     * Complete an Srm Asynch Request
     */
    bool completeRequest(
        glite::data::srm::util::Context::Ptr&           ctx, 
        glite::data::srm::util::details::AsynchRequest& request, 
        UrlCopyError::Category&                         c, 
        std::string&                                    m, 
        int                                             timeout) throw();

    /**
     * Abort an Srm Asynch Request
     */
    bool abortRequest(
        glite::data::srm::util::Context::Ptr&           ctx, 
        glite::data::srm::util::details::AsynchRequest& request, 
        UrlCopyError::Category&                         c, 
        std::string&                                    m, 
        int                                             timeout) throw();

    /** 
     * Execute an Srm Synch Request, retrying it in case of connection errors.
     * If the method invocation is succesfull, the category is set to SUCCESS,
     * and SrmStatus has to be checked 
     */
    glite::data::srm::util::SrmStatus executeRequest(
        glite::data::srm::util::Context::Ptr&           ctx, 
        glite::data::srm::util::details::SynchRequest&  request, 
        UrlCopyError::Category&                         c, 
        std::string&                                    m) throw();

protected:
    
    RefreshTimeUpdater::IUpdateRefreshTime * m_updateRefreshTime;
    
};

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif // GLITE_DATA_TRANSFER_URL_COPY_SRMMETHODCALLER_H_


