/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Utility functions for stat files
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <Zsolt.Molnar@cern.ch - www.zsoltmolnar.hu>
 *  Version info: $Id: StatCommon.cpp,v 1.4 2009/12/03 17:21:44 molnarzs Exp $
 *  Release: $Name:  $
 *
 */

#include <string.h>
#include "StatCommon.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

std::ostream& operator << (std::ostream& s, const ErrorStat& stat)
{
	s << "\t( int ) mm_scope: " << stat.mm_scope << "\n";
	s << "\t( int ) mm_phase: " << stat.mm_phase << "\n";
	s << "\t( int ) mm_category: " << stat.mm_category << "\n";
	s << "\t( char ) mm_message: " << stat.mm_message << "\n";

	return s;
}

std::ostream& operator << (std::ostream& s, const TransferStat& stat)
{
	s << "\t( unsigned int ) mm_version: " << stat.mm_version << "\n";
	s << "\t( unsigned int ) mm_extension: " << stat.mm_extension << "\n";
	s << "\t( unsigned int ) mm_id: " << stat.mm_id << "\n";
	s << "\t( time_t ) mm_start_time: " << stat.mm_start_time << "\n";
	s << "\t( time_t ) mm_finish_time: " << stat.mm_finish_time << "\n";
	s << "\t( time_t ) mm_last_refresh_time: " << stat.mm_last_refresh_time << "\n";
	s << "\t( unsigned int ) mm_pid: " << stat.mm_pid << "\n";
#ifdef _USE_GLOBAL_TIMEOUT
	s << "\t( int ) mm_global_timeout: " << stat.mm_global_timeout << "\n";
#endif
	s << "\t( unsigned int ) mm_verbose: " << stat.mm_verbose << "\n";
	s << "\t( unsigned int ) mm_flags: " << stat.mm_flags << "\n";
	s << "\t( unsigned int ) mm_overwrite: " << stat.mm_overwrite << "\n";
	s << "\t( char ) mm_dest_space_token: " << stat.mm_dest_space_token << "\n";
	s << "\t( char ) mm_dest_token_descr: " << stat.mm_dest_token_descr << "\n";
	s << "\t( char ) mm_user_tag: " << stat.mm_user_tag << "\n";
	s << "\t( char ) mm_source_space_token: " << stat.mm_source_space_token << "\n";
	s << "\t( char ) mm_source_token_descr: " << stat.mm_source_token_descr << "\n";
	s << "\t( unsigned int ) mm_enable_dir_check: " << stat.mm_enable_dir_check << "\n";
	s << "\t( unsigned int ) mm_enable_ping_source: " << stat.mm_enable_ping_source << "\n";
	s << "\t( unsigned int ) mm_enable_ping_dest: " << stat.mm_enable_ping_dest << "\n";
	s << "\t( unsigned int ) mm_block_after_preparation: " << stat.mm_block_after_preparation << "\n";
	s << "\t( unsigned int ) mm_block_after_transfer: " << stat.mm_block_after_transfer << "\n";
	s << "\t( int ) mm_copy_pin_lifetime: " << stat.mm_copy_pin_lifetime << "\n";
	s << "\t( int ) mm_lan_connection: " << stat.mm_lan_connection << "\n";
	s << "\t( int ) mm_fail_nearline_files: " << stat.mm_fail_nearline_files << "\n";
    s << "\t( int ) mm_syslog_disable: " << stat.mm_syslog_disable << "\n";
    s << "\t( char ) mm_syslog_ident: " << stat.mm_syslog_ident << "\n";
    s << "\t( int ) mm_syslog_facility: " << stat.mm_syslog_facility << "\n";
    s << "\t( char ) mm_syslog_facility_name: " << stat.mm_syslog_facility_name << "\n";

	return s;
}

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite
