/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: TransferConfig class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: TransferConfig.h,v 1.4 2007/11/08 08:48:26 ptedesco Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_TRANSFER_CONFIG_H_
#define GLITE_DATA_TRANSFER_URL_COPY_TRANSFER_CONFIG_H_

#include <string>
#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

class TransferConfig: boost::noncopyable {
public:    
    /**
     * Return singleton instance
     */
    static TransferConfig& instance() throw();
    
    /**
     * Return the glite-url-copy name
     */
    const char * name() const throw();

    /**
     * Return the mem extension
     */
    const char * extMem() const throw();

    /**
     * Return the log extension
     */
    const char * extLog() const throw();
    
    /**
     * Return the location where to store the mmap and the log files
     */
    std::string repository() const /*throw(RuntimeError)*/;

    /**
     * Return the location where to archive the mmap and the log files
     */
    std::string archive(bool completed, bool lost, const std::string& prefix = "") const /*throw(RuntimeError)*/;
    
private:
    /**
     * Constructor
     */
    TransferConfig(){}
    /**
     * Destructor
     */
    ~TransferConfig(){}
};

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_URL_COPY_TRANSFER_CONFIG_H_
