/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: TransferSrmCopyStat structure
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: TransferSrmCopyStat.cpp,v 1.7 2009/02/10 10:30:50 ptedesco Exp $
 *  Release: $Name:  $
 */
#include <glite/data/transfer/urlcopy/TransferSrmCopyStat.h>
#include <glite/data/transfer/urlcopy/UrlCopyError.h>
#include "SrmCopyStat.h"


using namespace glite::data::transfer::urlcopy;

/*
 * FileRequest
 *
 * Default Constructor
 */
TransferSrmCopyStat::FileRequest::FileRequest():
    exists(false),
    size(0),
    status(UrlCopyStatus::IDLE),
    start_time(0),
    done_time(0){
}

    
/*
 * TransferSrmCopyStat
 *
 * Default Constructor
 */
TransferSrmCopyStat::TransferSrmCopyStat(){
    // Status
    status               = UrlCopyStatus::IDLE;
    // Request Info
    start_time           = 0;
    finish_time          = 0;
    last_refresh_time    = 0;
    src_prep_start_time  = 0;
    src_prep_done_time   = 0;
    dest_prep_start_time = 0;
    dest_prep_done_time  = 0;
    copy_start_time      = 0;
    copy_done_time       = 0;
    final_start_time     = 0;
    final_done_time      = 0;

}

/*
 * TransferSrmCopyStat
 *
 * Constructor
 */
TransferSrmCopyStat::TransferSrmCopyStat(const struct SrmCopyStat * const stat){
    if(0 != stat){
        // Status
        status            = (UrlCopyStatus::Value)stat->mm_srmcopy.mm_status;
        // Error
        error.scope       = (UrlCopyError::Scope)stat->mm_srmcopy.mm_error.mm_scope;
        error.phase       = (UrlCopyError::Phase)stat->mm_srmcopy.mm_error.mm_phase;
        error.category    = (UrlCopyError::Category)stat->mm_srmcopy.mm_error.mm_category;
        error.description = stat->mm_srmcopy.mm_error.mm_message;
        // Request Info
        start_time           = stat->mm_common.mm_start_time;
        finish_time          = stat->mm_common.mm_finish_time;
        last_refresh_time    = stat->mm_common.mm_last_refresh_time;
        src_prep_start_time  = stat->mm_srmcopy.mm_src_prep_start_time;;
        src_prep_done_time   = stat->mm_srmcopy.mm_src_prep_done_time;
        dest_prep_start_time = stat->mm_srmcopy.mm_dest_prep_start_time;
        dest_prep_done_time  = stat->mm_srmcopy.mm_dest_prep_done_time;
        copy_start_time      = stat->mm_srmcopy.mm_start_time;
        copy_done_time       = stat->mm_srmcopy.mm_done_time;
        final_start_time     = stat->mm_srmcopy.mm_final_start_time;
        final_done_time      = stat->mm_srmcopy.mm_final_done_time;
        // Request Token 
        token                   = stat->mm_srmcopy.mm_token;
        // Destination Token
        destination_space_token = stat->mm_common.mm_dest_space_token;
        // User Description Tag
        user_tag                = stat->mm_common.mm_user_tag;
        // Set Files
        files.resize(stat->mm_num_files);
        // For Each File
        for(unsigned int i = 0; i < stat->mm_num_files; ++i){
            FileRequest& f       = files[i];
            const SrmCopy_FileStat& sf = stat->mm_files[i];
            f.src_name          = sf.mm_src_name;
            f.dest_name         = sf.mm_dest_name;
            f.exists            = (0 != sf.mm_dest_exists)?true:false;
            f.size              = sf.mm_size;
            f.status            = (UrlCopyStatus::Value)sf.mm_status;
            f.error.scope       = (UrlCopyError::Scope)sf.mm_error.mm_scope;
            f.error.phase       = (UrlCopyError::Phase)sf.mm_error.mm_phase;
            f.error.category    = (UrlCopyError::Category)sf.mm_error.mm_category;
            f.error.description = sf.mm_error.mm_message;
            f.start_time        = sf.mm_start_time;
            f.done_time         = sf.mm_done_time;
        }
    } else {
        // Status
        status               = UrlCopyStatus::IDLE;
        // Request Info
        start_time           = 0;
        finish_time          = 0;
        last_refresh_time    = 0;
        src_prep_start_time  = 0;
        src_prep_done_time   = 0;
        dest_prep_start_time = 0;
        dest_prep_done_time  = 0;
        copy_start_time      = 0;
        copy_done_time       = 0;
        final_start_time     = 0;
        final_done_time      = 0;

    }
}
