/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Checksum checking logic for Srm/Url copy
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: TransferUtils.h,v 1.1 2009/07/30 19:32:55 molnarzs Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_URL_TRANSFERUTILS_H_
#define GLITE_DATA_TRANSFER_URL_COPY_URL_TRANSFERUTILS_H_

#include "RefreshTimeUpdater.h"

#include <glite/data/srm/util/Context.h>
#include <glite/data/srm/util/PrepareToGet.h>
#include <glite/data/agents/glite-types.h>
#include <glite/data/transfer/urlcopy/UrlCopyError.h>

#include <boost/scoped_ptr.hpp>
#include <string>

const char * const PROTOCOL_GSIFTP    = "gsiftp";
const unsigned int MAX_GET_SLEEP_TIME = 30;

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

namespace TransferUtils {

struct PathInfo
{
    glite::data::agents::longlong                   file_size;
    glite::data::srm::util::FileLocality::Value     file_locality;
    std::string                                     cksm_algorithm;
    std::string                                     cksm_value;
    glite::data::srm::util::FileType::Value         file_type;

    PathInfo() :
        file_size(0),
        file_locality(glite::data::srm::util::FileLocality::UNDEF),
        file_type(glite::data::srm::util::FileType::UNDEF) {
    }
};

using glite::data::srm::util::Context;
using glite::data::srm::util::PrepareToGet;

bool SendPrepareToGet(
    Context::Ptr& ctx,
    RefreshTimeUpdater::IUpdateRefreshTime* updater,
    boost::scoped_ptr<PrepareToGet>& request,
    UrlCopyError::Category& c,
    std::string& m);

bool PollPrepareToGet (
	Context::Ptr& ctx,
    RefreshTimeUpdater::IUpdateRefreshTime* urt,
    boost::scoped_ptr<PrepareToGet>& request,
    int timeout,
    int start_time,
    unsigned int max_sleep_time,
    UrlCopyError::Category& c,
    std::string& m);


bool PathExists(
	RefreshTimeUpdater::IUpdateRefreshTime * updater,
    Context::Ptr&           ctx,
    const std::string&      surl,
    bool                    full_detailed,
    UrlCopyError::Category& c,
    std::string&            m,
    PathInfo&               pinfo);

void StatErrorFromSrmStatus(
    UrlCopyError::Category&                     c,
    std::string&                                m,
    const glite::data::srm::util::SrmStatus&    req_status,
    const glite::data::srm::util::SrmStatus&    file_status) throw();

void ErrorFromRequestStatus(
    UrlCopyError::Category&                     c,
    std::string&                                m,
    const glite::data::srm::util::SrmStatus&    req_status);

bool RmFile(
	RefreshTimeUpdater::IUpdateRefreshTime * updater,
	Context::Ptr& ctx,
	const std::string& surl,
	UrlCopyError::Category& c,
	std::string& m);

void RmErrorFromSrmStatus(
    UrlCopyError::Category& c,
    std::string& m,
    const glite::data::srm::util::SrmStatus& req_status,
    const glite::data::srm::util::SrmStatus& file_status);

} // namespace TransferUtils

} // namespace urlcopy
} // namespace transfer
} // namespace data
} // namespace glite

#endif // #ifndef GLITE_DATA_TRANSFER_URL_COPY_URL_TRANSFERUTILS_H_
