/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: UrlCopy Error definitions
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch> 
 *  Version info: $Id: UrlCopyError.cpp,v 1.11 2009/02/16 16:57:37 ptedesco Exp $
 *  Release: $Name:  $
 */

#include <glite/data/transfer/urlcopy/UrlCopyError.h>

using namespace glite::data::transfer::urlcopy;

// Macro used for the enumeration
#define EVAL_CASE_SCOPE(name) case SCOPE_## name: return #name;
#define EVAL_CASE_PHASE(name) case PHASE_## name: return #name;
#define EVAL_CASE_ERROR(name) case ERROR_## name: return #name;
    
/*
 * toString
 *
 * Return string representation of the Error Scope 
 */
const char * UrlCopyError::scopeToString(Scope value) throw(){
    switch(value){
    EVAL_CASE_SCOPE(SOURCE)
    EVAL_CASE_SCOPE(DESTINATION)
    EVAL_CASE_SCOPE(TRANSFER)
    EVAL_CASE_SCOPE(AGENT)
    default: return "";
    }
}

/*
 * toString
 *
 * Return string representation of the Error Phase
 */
const char * UrlCopyError::phaseToString(Phase value) throw(){
    switch(value){
    EVAL_CASE_PHASE(PREPARATION)
    EVAL_CASE_PHASE(FINALIZATION)
    EVAL_CASE_PHASE(TRANSFER)
    default: return "";
    }
}
    
/*
 * toString
 *
 * Return string representation of the Error Category
 */
const char * UrlCopyError::categoryToString(Category value) throw(){
    switch(value){
    EVAL_CASE_ERROR(USER)
    EVAL_CASE_ERROR(PERMISSION)
    EVAL_CASE_ERROR(FILE_EXISTS)
    EVAL_CASE_ERROR(INVALID_PATH)
    EVAL_CASE_ERROR(NO_SPACE_LEFT)
    EVAL_CASE_ERROR(GRIDFTP)
    EVAL_CASE_ERROR(NETWORK)
    EVAL_CASE_ERROR(INVALID_SIZE)
    EVAL_CASE_ERROR(REQUEST_FAILURE)
    EVAL_CASE_ERROR(CONNECTION)
    EVAL_CASE_ERROR(HTTP_TIMEOUT)
    EVAL_CASE_ERROR(REQUEST_TIMEOUT)
    EVAL_CASE_ERROR(TRANSFER_TIMEOUT)
    EVAL_CASE_ERROR(MARKERS_TIMEOUT)
    EVAL_CASE_ERROR(INTERNAL_ERROR)
    EVAL_CASE_ERROR(CONSISTENCY)
    EVAL_CASE_ERROR(ABORTED)
    EVAL_CASE_ERROR(GENERAL_FAILURE)
    EVAL_CASE_ERROR(LOST)
    EVAL_CASE_ERROR(STORAGE_INTERNAL_ERROR)
    EVAL_CASE_ERROR(SRM_COPY)
    EVAL_CASE_ERROR(LOCALITY)
    EVAL_CASE_ERROR(FIRST_MARKER_TIMEOUT)
    EVAL_CASE_ERROR(NO_PROGRESS)
    EVAL_CASE_ERROR(CHECKSUM_UNKNOWN)
    EVAL_CASE_ERROR(CHECKSUM_MISMATCH)
    default: return "";
    }
}

namespace std{

std::ostream& operator << (std::ostream& stream,UrlCopyError::Scope scope){
    return stream << UrlCopyError::scopeToString(scope);
}

std::ostream& operator << (std::ostream& stream,UrlCopyError::Phase phase){
    return stream << UrlCopyError::phaseToString(phase);
}

std::ostream& operator << (std::ostream& stream,UrlCopyError::Category category){
    return stream << UrlCopyError::categoryToString(category);
}

std::ostream& operator << (std::ostream& stream,const glite::data::transfer::urlcopy::UrlCopyError& error){
    stream << "[" << UrlCopyError::scopeToString(error.scope) << "] error during [" <<
        UrlCopyError::phaseToString(error.phase) << "]: [" << UrlCopyError::categoryToString(error.category) << "] " <<
        error.description;
    return stream;
}

} // std

