/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: UrlCopyStat structure
 *
 *  Authors: Zsolt Molnar <Zsolt.Molnar@cern.ch - www.zsoltmolnar.hu>
 *  Version info: $Id: UrlCopyStat.cpp,v 1.1 2009/05/04 12:47:54 molnarzs Exp $
 *  Release: $Name:  $
 */

#include "UrlCopyStat.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

std::ostream& operator << (std::ostream& s, const UrlCopy_FileRequestStat& stat)
{
	s << "\t( char ) mm_srm_endpoint: " << stat.mm_srm_endpoint << "\n";
	s << "\t( char ) mm_srm_version: " << stat.mm_srm_version << "\n";
	s << "\t( char ) mm_name: " << stat.mm_name << "\n";
	s << "\t( char ) mm_tx_name: " << stat.mm_tx_name << "\n";
	s << "\t( char ) mm_token: " << stat.mm_token << "\n";
	s << "\t( unsigned int ) mm_exists: " << stat.mm_exists << "\n";
	s << "\t( int ) mm_type: " << stat.mm_type << "\n";
	s << "\t( glite::data::agents::longlong ) mm_size: " << stat.mm_size << "\n";
	s << "\t( time_t ) mm_prep_start_time: " << stat.mm_prep_start_time << "\n";
	s << "\t( time_t ) mm_prep_done_time: " << stat.mm_prep_done_time << "\n";
	s << "\t( time_t ) mm_final_start_time: " << stat.mm_final_start_time << "\n";
	s << "\t( time_t ) mm_final_done_time: " << stat.mm_final_done_time << "\n";
	s << "\t( ErrorStat ) mm_error: " << stat.mm_error << "\n";
	s << "\t( int ) mm_http_timeout: " << stat.mm_http_timeout << "\n";
	s << "\t( int ) mm_prep_timeout: " << stat.mm_prep_timeout << "\n";
	s << "\t( int ) mm_final_timeout: " << stat.mm_final_timeout << "\n";

	return s;
}

std::ostream& operator << (std::ostream& s, const UrlCopy_FileTransferStat& stat)
{
	s << "\t( time_t ) mm_start_time: " << stat.mm_start_time << "\n";
	s << "\t( time_t ) mm_done_time: " << stat.mm_done_time << "\n";
	s << "\t( time_t ) mm_first_marker: " << stat.mm_first_marker << "\n";
	s << "\t( time_t ) mm_last_marker: " << stat.mm_last_marker << "\n";
	s << "\t( glite::data::agents::longlong ) mm_size: " << stat.mm_size << "\n";
	s << "\t( glite::data::agents::longlong ) mm_transferred_bytes: " << stat.mm_transferred_bytes << "\n";
	s << "\t( float ) mm_avg_throughput: " << stat.mm_avg_throughput << "\n";
	s << "\t( float ) mm_instant_throughput: " << stat.mm_instant_throughput << "\n";
	s << "\t( float ) mm_percent_done: " << stat.mm_percent_done << "\n";
	s << "\t( int ) mm_markers: " << stat.mm_markers << "\n";
	s << "\t( ErrorStat ) mm_error: " << stat.mm_error << "\n";
	s << "\t( int ) mm_streams: " << stat.mm_streams << "\n";
	s << "\t( int ) mm_tcp_bs: " << stat.mm_tcp_bs << "\n";
	s << "\t( int ) mm_timeout: " << stat.mm_timeout << "\n";
	s << "\t( int ) mm_marker_timeout: " << stat.mm_marker_timeout << "\n";
	s << "\t( int ) mm_first_marker_timeout: " << stat.mm_first_marker_timeout << "\n";
	s << "\t( time_t ) mm_gridftp_copy_start_time: " << stat.mm_gridftp_copy_start_time << "\n";
	s << "\t( int ) mm_no_progress_timeout: " << stat.mm_no_progress_timeout << "\n";
	s << "\t( double ) mm_tx_to_per_mb: " << stat.mm_tx_to_per_mb << "\n";
	s << "\t( time_t ) mm_last_progress_marker: " << stat.mm_last_progress_marker << "\n";

	return s;
}

std::ostream& operator << (std::ostream& s, const UrlCopy_FileStat& stat)
{
	s << "\t( unsigned int ) mm_status: " << stat.mm_status << "\n";
	s << "\t( UrlCopy_FileRequestStat ) mm_source: " << stat.mm_source << "\n";
	s << "\t( UrlCopy_FileRequestStat ) mm_destination: " << stat.mm_destination << "\n";
	s << "\t( UrlCopy_FileTransferStat ) mm_tx: " << stat.mm_tx << "\n";
	s << "\t( ErrorStat ) mm_error: " << stat.mm_error << "\n";
	s << "\t( int ) mm_compare_checksum: " << stat.mm_compare_checksum << "\n";
	s << "\t( char ) mm_checksum_user_algorithm: " << stat.mm_checksum_user_algorithm << "\n";
	s << "\t( char ) mm_checksum_user_value: " << stat.mm_checksum_user_value << "\n";
	s << "\t( char ) mm_src_checksum_algorithm: " << stat.mm_src_checksum_algorithm << "\n";
	s << "\t( char ) mm_src_checksum_value: " << stat.mm_src_checksum_value << "\n";
	s << "\t( char ) mm_dst_checksum_algorithm: " << stat.mm_dst_checksum_algorithm << "\n";
	s << "\t( char ) mm_dst_checksum_value: " << stat.mm_dst_checksum_value << "\n";

	return s;
}

std::ostream& operator << (std::ostream& s, const UrlCopyStat& stat)
{
	s << "-> (TransferStat) mm_common:\n" << stat.mm_common
	  << "-> (UrlCopy_FileStat) mm_urlcopy:\n" << stat.mm_urlcopy << std::endl;

	return s;
}

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite
