/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: UrlCopyStat structure
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <Zsolt.Molnar@cern.ch - www.zsoltmolnar.hu>
 *  Version info: $Id: UrlCopyStat.h,v 1.15 2009/05/04 12:26:50 molnarzs Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_URL_COPY_STAT_H_
#define GLITE_DATA_TRANSFER_URL_COPY_URL_COPY_STAT_H_

#include <glite/data/agents/glite-types.h>
#include "StatCommon.h"
#include <time.h>
#include <ostream>

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

/**
 * UrlCopy Stat Version
 */
#define URLCOPY_STAT_EXTENSION    0x00000001

#define URLCOPY_STAT_ID           0xaaaaaaaa

/**
 * UrlCopy File Request Stat Structure
 */
struct UrlCopy_FileRequestStat {
    char         mm_srm_endpoint[TRANSFER_STAT_URL_LEN];
    char         mm_srm_version [TRANSFER_STAT_VERSION_LEN];
    char         mm_name        [TRANSFER_STAT_URL_LEN];
    char         mm_tx_name     [TRANSFER_STAT_URL_LEN];
    char         mm_token       [TRANSFER_STAT_TOKEN_LEN];
    unsigned int mm_exists;
    int          mm_type;
    glite::data::agents::longlong mm_size;
    time_t       mm_prep_start_time;
    time_t       mm_prep_done_time;
    time_t       mm_final_start_time;
    time_t       mm_final_done_time;
    // Error
    ErrorStat    mm_error;
    // Configuration
    int          mm_http_timeout;
    int          mm_prep_timeout;
    int          mm_final_timeout;
};

std::ostream& operator << (std::ostream& s, const UrlCopy_FileRequestStat& stat);

/**
 * UrlCopy File Transfer Stat Structure
 */
struct UrlCopy_FileTransferStat {
    time_t    mm_start_time;
    time_t    mm_done_time;
    time_t    mm_first_marker;
    time_t    mm_last_marker;
    glite::data::agents::longlong mm_size;
    glite::data::agents::longlong mm_transferred_bytes;
    float     mm_avg_throughput;
    float     mm_instant_throughput;
    float     mm_percent_done;
    int       mm_markers;
    // Error
    ErrorStat mm_error;
    // Configuration
    int       mm_streams;
    int       mm_tcp_bs;
    int       mm_block_size; // Specifies the size (in bytes) of the buffer to be used by the underlying transfer methods.
    int       mm_timeout;
    int       mm_marker_timeout;
    int       mm_first_marker_timeout;
    time_t    mm_gridftp_copy_start_time;
    int       mm_no_progress_timeout;
    double    mm_tx_to_per_mb;
    // time the last marker indicating a progress (i.e. different from the
    // previous one) was received
    time_t    mm_last_progress_marker;
};

std::ostream& operator << (std::ostream& s, const UrlCopy_FileTransferStat& stat);

// note: renamed UrlCopy_Stat to UrlCopy_FileStat for clarity
/**
 * File Stat Structure
 */
struct UrlCopy_FileStat {
    // Transfer Request Status
    unsigned int                mm_status;
    // Source File
    UrlCopy_FileRequestStat     mm_source;
    // Destination File
    UrlCopy_FileRequestStat     mm_destination;
    // Transfer
    UrlCopy_FileTransferStat    mm_tx;
    // The main reason why the transfer failed
    ErrorStat                   mm_error;
    // added with stat version 3.5.0
    // flag specifying if checksums should be compared
    int                         mm_compare_checksum;
    // checksum algorithm specified by the user
    char                        mm_checksum_user_algorithm[CHECKSUM_ALGORITHM_LEN];
    // checksum value specified by the user
    char                        mm_checksum_user_value[CHECKSUM_VALUE_LEN];
    // src checksum algorithm (got with srmLs or gridftp)
    char         mm_src_checksum_algorithm[CHECKSUM_ALGORITHM_LEN];
    // src checksum value (got with srmLs or gridftp)
    char         mm_src_checksum_value[CHECKSUM_VALUE_LEN];
    // dst checksum algorithm (got with srmLs or gridftp)
    char         mm_dst_checksum_algorithm[CHECKSUM_ALGORITHM_LEN];
    // dst checksum value (got with srmLs or gridftp)
    char         mm_dst_checksum_value[CHECKSUM_VALUE_LEN];
};

std::ostream& operator << (std::ostream& s, const UrlCopy_FileStat& stat);

/**
 * UrlCopy Stat Structure
 */
struct UrlCopyStat {
    // Transfer Stat
    TransferStat mm_common;
    // File
    UrlCopy_FileStat mm_urlcopy;
};

std::ostream& operator << (std::ostream& s, const UrlCopyStat& stat);

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_URL_COPY_URL_COPY_STAT_H_
