/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Checksum checking logic for Srm/Url copy
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: UrlCopyUtils.h,v 1.1 2009/07/30 19:32:55 molnarzs Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_URL_URLCOPYUTILS_H_
#define GLITE_DATA_TRANSFER_URL_COPY_URL_URLCOPYUTILS_H_

#include "logger-utility.h"
#include "stat-utility.h"

#include <glite/data/srm/util/types.h>
#include <string>

const unsigned int DEFAULT_GET_TIMEOUT = 180;

//------------------------------------------------------------------------------
// Enable this flag in order to set the request lifetimes so the SRM would abort
// the request and do an internal cleanup even in case transfer-url-copy is
// not able to properly complete the clenaup procedue
//#define USE_SAFE_CLEANUP
//------------------------------------------------------------------------------

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

namespace UrlCopyUtils {

using namespace glite::data::srm::util;

void SourceErrorFromSrmStatus(
    const SrmStatus&        req_status,
    const SrmStatus&        file_status,
    UrlCopyError::Category& c,
    std::string&            m);

void DestinationErrorFromSrmStatus(
    const SrmStatus&        req_status,
    const SrmStatus&        file_status,
    UrlCopyError::Category& c,
    std::string&            m);

template<class STAT>
void SetScopeError(
	STAT&                   stat,
	UrlCopyError::Scope     scope,
    UrlCopyError::Phase     p,
    UrlCopyError::Category  c,
    const std::string&      m) throw()
{
    // Set Source Error
    stat.mm_error.mm_scope    = scope;
    stat.mm_error.mm_phase    = p;
    stat.mm_error.mm_category = c;
    copy_message(stat.mm_error.mm_message, m.c_str());
    error() << UrlCopyError::scopeToString(scope) << " failed during " << UrlCopyError::phaseToString(p)
            << " phase. Error [" << UrlCopyError::categoryToString(c) << "]:" << m;
}

void SetFinalError(
	UrlCopy_FileStat&       stat,
    UrlCopyError::Scope     s,
    UrlCopyError::Phase     p = UrlCopyError::PHASE_UNDEF,
    UrlCopyError::Category  c = UrlCopyError::SUCCESS,
    const std::string&      m = "");

} // namespace UrlCopyUtils

} // namespace urlcopy
} // namespace transfer
} // namespace data
} // namespace glite

#endif // #ifndef GLITE_DATA_TRANSFER_URL_COPY_URL_URLCOPYUTILS_H_
