/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  gLite Transfer Url Copy Clients - glite-srm-copy Exec Tool
 *
 *  Authors: Paolo Badino <Paolo.Badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: glite-srm-copy-exec.cpp,v 1.5 2008/10/20 09:01:44 ptedesco Exp $
 *  Release: $Name:  $
 *
 */

#include "util-main.h"
#include <glite/data/transfer/urlcopy/TransferSrmCopy.h>

#include <glite/data/agents/AgentExceptions.h>
#include <glite/data/agents/url-utility.h>

#include <boost/algorithm/string.hpp>

using namespace glite::data::agents;
using namespace glite::data::agents::options;
using namespace glite::data::transfer::urlcopy;

namespace {
bool g_console_logging = false;
} // end global namespace

/**
 * tool_add_args
 */
void tool_add_args(Arguments& args){
    // options
    opt(g_console_logging,true,args,'C',"console-logging").help("enable console logging.");
    // positional parameters
    args.pos("request_id").help("the identifier of the transfer request.");
}

/*
 * tool_doit
 * 
 * Serve the transfer request
 */
int tool_doit(int argc, char *argv[]){

    if((argc < 1) || (0 == argv[0])){
        tool_error() << "No transfer request id specified" << std::endl;
        return EXIT_FAILURE;
    }
    

    std::string request_id = argv[0];    
    
    // Open the stat File
    int result = EXIT_FAILURE;
    TransferSrmCopy::Ptr tx;
    try {
        // Run transfer in blocking mode
        tx = TransferSrmCopy::get(request_id);
        // Transfer is now completed (successfully or not)

	std::string vo = argv[1];
	std::string src_site = argv[2];
	std::string dest_site = argv[3];	        
        // Execute transfer in blocking mode
        tx->exec(g_console_logging, vo, src_site, dest_site);

        // Get transfer status
        TransferSrmCopyStat tx_stat = tx->status();
        if((tx_stat.error.category == UrlCopyError::SUCCESS) &&
           (tx_stat.status == UrlCopyStatus::COMPLETED)){
            // Transfer is success
            result = EXIT_SUCCESS;
            // TODO Print File statuses
        } else {
            // Transfer failed
            result = EXIT_FAILURE;
            // TODO Print Error reason
        }
    } catch(const std::exception& exc){
        tool_error() << "Invalid transfer request id: " << exc.what() << std::endl;
        return EXIT_FAILURE;
    }
    return result;
}

