/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  gLite Transfer Url Copy Clients - glite-url-copy-continue tool
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: glite-url-copy-continue.cpp,v 1.5 2008/10/20 09:01:44 ptedesco Exp $
 *  Release: $Name:  $
 *
 */

#include "util-main.h"
#include <glite/data/transfer/urlcopy/TransferUrlCopy.h>
#include <glite/data/transfer/urlcopy/TransferSrmCopy.h>
#include "stat-utility.h"
#include "logger-utility.h"

#include <glite/data/agents/AgentExceptions.h>
#include <glite/data/agents/url-utility.h>

#include <boost/algorithm/string.hpp>
#include <signal.h>

using namespace glite::data::agents;
using namespace glite::data::agents::options;
using namespace glite::data::transfer::urlcopy;

/**
 * tool_add_args
 */
void tool_add_args(Arguments& args){
    // positional parameters
    args.pos("request_id").help("the identifier of the transfer request.");
}

/*
 * stop_transfer
 * 
 * Stop The Transfer
 */
template <typename T,typename S>
int continue_transfer(T& tx){
    try{
        // send the signal to continue the transfer
        tx.continueTransfer();
        tool_info() << "Signal sent to continue the transfer." << std::endl;
        return EXIT_SUCCESS;
    } catch(const RuntimeError& exc){
        // This should not happen. Anyway call abort
        tool_error() << "Error sending signal to continue transfer: " << exc.what() << std::endl;
        return EXIT_FAILURE;
    }
}

/*
 * tool_doit
 */
int tool_doit(int argc, char *argv[]){
    int result = EXIT_FAILURE;
    
    if((argc < 1) || (0 == argv[0])){
        tool_error() << "No transfer request id specified" << std::endl;
        return EXIT_FAILURE;
    }
    if(argc > 1){
        tool_error() << "Too many request id specified" << std::endl;
        return EXIT_FAILURE;
    }
    std::string request_id = argv[0];    

    try {
        // Get the TransferUrlCopy objects
        TransferUrlCopy::Ptr utx = TransferUrlCopy::get(request_id);
        // Stop the transfer
        result = continue_transfer<TransferUrlCopy,TransferUrlCopyStat>(*utx);
    } catch(const std::exception& exc){
        try{
            // Not an Urlcopy Request: try if it's an SrmCopy One
            TransferSrmCopy::Ptr stx = TransferSrmCopy::get(request_id);
            // Stop the transfer
            result = continue_transfer<TransferSrmCopy,TransferSrmCopyStat>(*stx);
        } catch(const std::exception& exc){
            tool_error() << "Invalid transfer request id. Not a urlcopy nor a srmcopy valid transfer" << std::endl;
            result = EXIT_FAILURE;
        }
    }
    
    return result;
}

