/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  gLite Transfer Url Copy Clients - glite-url-copy-status Tool
 *
 *  Authors: Paolo Badino <Paolo.Badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: glite-url-copy-print-status.cpp,v 1.7 2008/11/17 15:38:51 ptedesco Exp $
 *  Release: $Name:  $
 *
 */

#include "util-main.h"
#include <glite/data/transfer/urlcopy/TransferUrlCopy.h>
#include <glite/data/transfer/urlcopy/TransferSrmCopy.h>
#include "stat-utility.h"
#include "logger-utility.h"

#include <glite/data/agents/AgentExceptions.h>
#include <glite/data/agents/url-utility.h>

#include <boost/algorithm/string.hpp>

using namespace glite::data::agents;
using namespace glite::data::agents::options;
using namespace glite::data::transfer::urlcopy;

/**
 * tool_add_args
 */
void tool_add_args(Arguments& args){
    // positional parameters
    args.pos("stat_file").help("path of the transfer parameters (.mem) file.");
}

/*
 * tool_doit
 */
int tool_doit(int argc, char *argv[]){
    int result = EXIT_FAILURE;
    
    if((argc < 1) || (0 == argv[0])){
        tool_error() << "No transfer stat file name specified" << std::endl;
        return EXIT_FAILURE;
    }
    if(argc > 1){
        tool_error() << "Too many file names specified" << std::endl;
        return EXIT_FAILURE;
    }
    std::string file_name = argv[0];    

    try {
        // Try with TransferUrlCopy
        tool_debug() << "Checking status of TransferUrlCopy request." << std::endl;
        TransferUrlCopy::dump(file_name);
        result = EXIT_SUCCESS;
    } catch(const std::exception& exc){
        tool_debug() << "Checking status of TransferUrlCopy request failed: " << exc.what() << std::endl;
        try{
            // Try with TransferSrmCopy
            tool_debug() << "Checking status of TransferSrmCopy request." << std::endl;
            TransferSrmCopy::dump(file_name);
            result = EXIT_SUCCESS;
        } catch(const std::exception& exc){
            tool_debug() << "Checking status of TransferSrmCopy request failed: " << exc.what() << std::endl;
            tool_error() << "Invalid transfer stat file. Not a urlcopy nor a srmcopy valid transfer" << std::endl;
            result = EXIT_FAILURE;
        }
    }
    return result;
}

