/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: gridftp helper methods 
 *   refactored from previous transfer-url-copy (Peter Kunszt) and lcg_util 
 *   (Jean-Philippe Baud)
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: gridftp-utility.h,v 1.11 2009/02/10 10:28:36 ptedesco Exp $
 *  Release: $Name:  $
 */
 
#ifndef GLITE_DATA_TRANSFER_URL_COPY_GRIDFTP_UTILITY_H_
#define GLITE_DATA_TRANSFER_URL_COPY_GRIDFTP_UTILITY_H_

#include <glite/data/transfer/urlcopy/UrlCopyError.h>
#include <glite/data/transfer/urlcopy/UrlCopyStatus.h>
#include <glite/data/agents/glite-types.h>

#include "PerfMarker.h"
#include "RefreshTimeUpdater.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {
    
/**
 * gridftp_getfilesize
 * Get the size of a file using gsiftp. The error scope is known by the caller. 
 * @param name [IN] file name
 * @param category [OUT] error category
 * @param category [OUT] error message
 * @param timeout [IN] timeout
 * @param ftph [IN] the gridftp handle
 * @return file size
 */    
glite::data::agents::longlong gridftp_getfilesize(
    const std::string&      name, 
    UrlCopyError::Category& category, 
    std::string&            message, 
    int                     timeout) /* throw () */;
    
/** 
 * gridftp_copy
 * Copy a file using gsiftp
 * @param src_file [IN] source file
 * @param dest_file [IN] destination file
 * @param category [OUT] error category
 * @param scope [OUT] error scope
 * @param category [OUT] error message
 * @param nbstreams [IN] number of streams
 * @param tcpbs [IN] tcp buffer size
 * @param block_size [IN] block size
 * @param timeout [IN] timeout
 * @param cp_callback [IN] copy callback
 * @param user_arg [IN] 
 * @param iupdater [IN] IUpdateRefreshTime interface pointer
 */    
void gridftp_copy(
    const std::string&                          src_file, 
    const std::string&                          dest_file, 
    UrlCopyError::Category&                     category, 
    UrlCopyError::Scope&                        scope, 
    std::string&                                message, 
    int const                                   nbstreams, 
    int const                                   tcpbs, 
    int const                                   block_size,
    int const                                   timeout, 
    gridftpcopy_callback_t                      cp_callback, 
    void *                                      user_arg,
    RefreshTimeUpdater::IUpdateRefreshTime *    iupdater,
    bool gsiftpOverwrite) /* throw () */;

/**
 * gridftp_checksum
 * Get a file checksum
 * @param ftph [IN] the gridftp handle
 * @param turl [IN] the TURL of the file
 * @param algorithm [IN] the checksum algorithm
 * @param timeout [IN] timeout for the operation
 * @param category [OUT] error category
 * @param message [OUT] error message
 * @param iupdater [IN] pointer to IUpdateRefreshTime
 * @return file checksum if successful, empty string otherwise
 */
std::string gridftp_checksum(
    const std::string&                          turl,
    const std::string&                          algorithm,
    int                                         timeout,
    UrlCopyError::Category&                     category, 
    std::string&                                message, 
    RefreshTimeUpdater::IUpdateRefreshTime *    iupdater) /* throw () */;
    
/**
 * gridftp_rmfile
 * Delete a file.
 * @param ftph [IN] the gridftp handle
 * @param turl [IN] the TURL of the file
 * @param timeout [IN] timeout for the operation
 * @param category [OUT] error category
 * @param message [OUT] error message
 * @param iupdater [IN] pointer to IUpdateRefreshTime
 */
void gridftp_rmfile(
    const std::string&                          turl,
    int                                         timeout,
    UrlCopyError::Category&                     category,
    std::string&                                message,
    RefreshTimeUpdater::IUpdateRefreshTime *    iupdater);
    
} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite


#endif //GLITE_DATA_TRANSFER_URL_COPY_GRIDFTP_UTILITY_H_
