/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Transfer signal Handler helper methods
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>, Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: sighandler-utility.cpp,v 1.6 2008/08/06 12:17:35 ptedesco Exp $
 *  Release: $Name:  $
 */
#include "sighandler-utility.h"
#include "logger-utility.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

/**
 * Signal to stop the transfer
 */
const int SigAction::SIGNAL_STOP = SIGINT;

/**
 * Signal to continue the transfer
 */
const int SigAction::SIGNAL_CONTINUE = SIGUSR2;
    
/**
 * sigstop_handler
 * signal handler for stopping the transfer
 */    
void sigstop_handler(int){
    warn() << "signal received to cancel transfer request";
    TransferState::instance().interrupt();
}

/**
 * sigcontinue_handler
 * signal handler to continue the process if it's blocked after preparation/transfer
 */    
void sigcontinue_handler(int){
    info() << "signal received to continue the transfer";
    TransferState::instance().set_continueTransfer(true);
}

/**
 * Constructor
 */
SigAction::SigAction(){
    // SIGNAL_STOP
    m_sigstop.sa_handler = &sigstop_handler;
    sigemptyset(&m_sigstop.sa_mask);
    m_sigstop.sa_flags = 0;
    if (sigaction(SIGNAL_STOP,&m_sigstop,&m_sigstop_old) < 0){
        error() << "Failed registering handler for stop signal";
    } else {
        debug() << "Registered handler for stop signal";
    }
    // SIGNAL_CONTINUE
    m_sigcontinue.sa_handler = &sigcontinue_handler;
    sigemptyset(&m_sigcontinue.sa_mask);
    m_sigcontinue.sa_flags = 0;
    if (sigaction(SIGNAL_CONTINUE,&m_sigcontinue,&m_sigcontinue_old) < 0){
        error() << "Failed registering handler for continue signal";
    } else {
        debug() << "Registered handler for continue signal";
    }
}

/**
 * Destructor
 */
SigAction::~SigAction(){
    // restore signal actions
    debug() << "Restoring previous signal handlers";
    sigaction(SIGNAL_STOP, &m_sigstop_old, 0);
    sigaction(SIGNAL_CONTINUE, &m_sigcontinue_old, 0);
}

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite
