/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: UrlCopyStat structure
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: stat-utility.h,v 1.10 2009/12/03 17:21:44 molnarzs Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_STAT_UTILITY_H_
#define GLITE_DATA_TRANSFER_URL_COPY_STAT_UTILITY_H_

#include <glite/data/transfer/urlcopy/UrlCopyStatus.h>

#include "UrlCopyStat.h"
#include <glite/data/transfer/urlcopy/TransferUrlCopy.h>
#include <glite/data/transfer/urlcopy/TransferUrlCopyStat.h>

#include "SrmCopyStat.h"
#include <glite/data/transfer/urlcopy/TransferSrmCopy.h>
#include <glite/data/transfer/urlcopy/TransferSrmCopyStat.h>

#include "Mmap.h"

#include <string>
#include <boost/shared_ptr.hpp>
#include <cstring>

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

/**
 * Create a stat File for UrlCopy and return the Mmap object for it
 */
boost::shared_ptr<Mmap> create_stat_UrlCopy(const std::string& name) /*throw (RuntimeError, LogicError)*/;

/**
 * Create a stat File for SrmCopy and return the Mmap object for it
 */
boost::shared_ptr<Mmap> create_stat_SrmCopy(const std::string& name, unsigned int num_files) /*throw (RuntimeError, LogicError)*/;

/**
 * Open a stat File, guess it's type, check it's validity and return the Mmap object for it
 */
boost::shared_ptr<Mmap> open_stat_file(const std::string& file_name, bool read_only, unsigned int requested_stat_id) /*throw (RuntimeError, LogicError)*/;

/**
 * Open a stat File, guess it's type, check it's validity and return the Mmap object for it
 */
boost::shared_ptr<Mmap> open_stat(
    const std::string&  name,
    bool                read_only,
    unsigned int        requested_stat_id = 0,
    bool                search_subfolders = true) /*throw (RuntimeError, LogicError)*/;

/**
 * Open a stat File for UrlCopy, check it's validity and return the Mmap object for it
 */
boost::shared_ptr<Mmap> open_stat_UrlCopy(
    const std::string&  name,
    bool                read_only,
    bool                search_subfolders = true) /*throw (RuntimeError, LogicError)*/;

/**
 * Open a stat File for SrmCopy, check it's validity and return the Mmap object for it
 */
boost::shared_ptr<Mmap> open_stat_SrmCopy(
    const std::string&  name,
    bool                read_only,
    bool                search_subfolders = true) /*throw (RuntimeError, LogicError)*/;

/**
 * Copy an URL string
 */
inline void copy_url(char * d, const char * s) throw (){
    strncpy(d,s,TRANSFER_STAT_URL_LEN - 1);
}
/**
 * Copy a Version string
 */
inline void copy_version(char * d, const char * s) throw (){
    strncpy(d,s,TRANSFER_STAT_VERSION_LEN - 1);
}
/**
 * Copy a Token string
 */
inline void copy_token(char * d, const char * s) throw (){
    strncpy(d,s,TRANSFER_STAT_TOKEN_LEN - 1);
}
/**
 * Copy a Message string
 */
inline void copy_message(char * d, const char * s) throw (){
    strncpy(d,s,TRANSFER_STAT_MESSAGE_LEN - 1);
}

inline void copy_syslog_facility_name(char * d, const char * s) throw ()
{
    strncpy(d, s, SYSLOG_FACILITY_NAME_LEN - 1);
}

inline void copy_syslog_ident(char * d, const char * s) throw ()
{
    strncpy(d, s, SYSLOG_IDENT_LEN - 1);
}


/*------------------------------------------------------------------------------
                            Conversion Utilities
------------------------------------------------------------------------------*/

/**
 * Convert TransferUrlCopy::Args to UrlCopyStat
 * @param args [IN]
 * @param stat [OUT]
 */
void transferUrlCopyArgs_to_UrlCopyStat(
    const TransferUrlCopy::Args&    args,
    UrlCopyStat&                    stat);

/**
 * Convert TransferSrmCopy::Args to SrmCopyStat
 * @param args [IN]
 * @param stat [OUT]
 */
void transferSrmCopyArgs_to_SrmCopyStat(
    const TransferSrmCopy::Args&    args,
    SrmCopyStat&                    stat);

inline void copy_checksum_algorithm(char * d, const char * s) throw (){
    strncpy(d,s,CHECKSUM_ALGORITHM_LEN - 1);
}
inline void copy_checksum_value(char * d, const char * s) throw (){
    strncpy(d,s,CHECKSUM_VALUE_LEN - 1);
}

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_URL_COPY_STAT_UTILITY_H_
