/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Transfer helper methods
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: transfer-utility.h,v 1.7 2008/10/24 13:54:45 ptedesco Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_TRANSFER_URL_COPY_URL_TRANSFER_UTILITY_H_
#define GLITE_DATA_TRANSFER_URL_COPY_URL_TRANSFER_UTILITY_H_

#include <glite/data/transfer/urlcopy/details/TransferBase.h>
#include "StatCommon.h"
#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {
    
/**
 * Create the Repository and Archive directory
 */
void setup_repository(const std::string& prefix) /*throw(RuntimeError)*/;

/**
 * Generate a new (unique) request id
 */
std::string generate_request_id(const std::string& prefix) throw();

/**
 * Execute the transfer
 */
void execute_transfer(details::TransferBase& tx,bool blocking, bool console_logging, std::string vo, std::string src_site, std::string dst_site) /* throw (RuntimeError) */;

/**
 * archive log and mem files
 */
void archive_files(const details::TransferBase& tx, bool is_success,bool is_lost) throw ();

/**
 * Verify that given command line file contains the given executable name and 
 * transfer id.
 * @param file_path [IN] the path of the command line file to open
 * @param exec_name [IN] the executable name
 * @param tx_id [IN] the transfer id
 * @param reason [OUT] the reason for which the check failed
 */
bool check_cmdline_file(
    const std::string& file_path,
    const std::string& exec_name,
    const std::string& tx_id,
    std::string& reason);

/**
 * Check that the transfer process serving the request is still active
 */
bool is_running(const details::TransferBase& tx, pid_t pid) throw();

/**
 * Check that the transfer process serving the request is still active and
 * provide a description why the check failed
 */
bool is_running_with_reason(const details::TransferBase& tx, pid_t pid,std::string& reason) throw();

/** 
 * check_transfer
 *
 * Check that the transfer process is updating the stat file periodically
 * @param tx [IN] the TransferBase object
 * @param stat [IN] the TransferStat object
 * @param check [IN] if true, the last update time will be checked
 * @param status [IN] the UrlCopyStatus for the transfer
 * @param refresh_delay [IN] the maximum amount of time from the last update 
 * time refresh after which the transfer is considered not responding. If set to
 * -1 the refresh delay is not checked
 */
void check_transfer(
    const details::TransferBase& tx, 
    const TransferStat& stat, 
    bool check, 
    unsigned int status, 
    int refresh_delay) /*throw(RuntimeError)*/;

/*
 * Stop the running transfer. Return 0 is success, -1 if failed and and 1 if the
 * stat should be refreshed
 */
int stop_transfer(const details::TransferBase& tx, const TransferStat& stat, unsigned int status) /*throw(RuntimeError)*/;
 
/**
 * Abort a Running Transfer
 */
void abort_transfer(const details::TransferBase& tx, pid_t pid, unsigned int& status, ErrorStat& error_stat) /*throw()*/;

} // namespace urlcopy
} // namespace transfer
} // namespace data
} // namespace glite

#endif //GLITE_DATA_TRANSFER_URL_COPY_URL_TRANSFER_UTILITY_H_
