/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  gLite Transfer Url Copy Clients - Main function for the CLI
 *
 *  Authors: Paolo Badino <Paolo.Badino@cern.ch>,
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: util-main.cpp,v 1.8 2008/10/20 09:03:05 ptedesco Exp $
 *  Release: $Name:  $
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "util-main.h"
#include <glite/data/glite-util.h>
#include "stat-utility.h"
#include <glite/data/transfer/urlcopy/UrlCopyError.h>
#include "FileType.h"

#include <getopt.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <stdarg.h>

using namespace glite::data::transfer::urlcopy;
using namespace glite::data::agents::options;

// -----------------------------------------------------------------------------
// Global variables
// -----------------------------------------------------------------------------

// Flag to turn on verbose output
int verbose_flag = 0;
// Flag to request quiet operation
int quiet_flag = 0;
// show help flag 
bool show_help = false;
// show version flag
bool show_version = false;

// -----------------------------------------------------------------------------
// Logging functions
// -----------------------------------------------------------------------------
namespace{
    std::ostream nullstream(0);
}

/**
 * tool_debug
 */
std::ostream& tool_debug(){
    if (verbose_flag) {
        return std::cout;
    } else {
        return nullstream;
    }
}

/**
 * tool_info
 */
std::ostream& tool_info(){
    return std::cout;
}

/**
 * tool_error
 */
std::ostream& tool_error(){
    return std::cerr;
}

// -----------------------------------------------------------------------------
void opt_quiet(char*){
    ++quiet_flag;
    verbose_flag = 0;
}
void opt_verbose(char*){
    ++verbose_flag;
    quiet_flag = 0;
}

/**
 * main
 * Main routine for the gLite SRM tools
 */
int main(int argc, char *argv[]) {
    // arguments parser
    Arguments args(argc,argv,tool_info(),tool_error());
    try{
        // add common options
        opt(show_help,true,     args,'h',"help")     .help("Print this help text and exit.");
        opt(opt_quiet,          args,'q',"quiet")    .help("Quiet operation.");
        opt(opt_verbose,        args,'v',"verbose")  .help("Be more verbose.");
        opt(show_version,true,  args,'V',"version")  .help("Print the version number and exit.");
        tool_add_args(args);
    } catch(const std::exception& exc){
        tool_error() << exc.what() << std::endl;
        return EXIT_FAILURE;
    }
    
    if (!args.parse()){
        args.showHelp();
        return EXIT_FAILURE;
    }
    if (show_help){
        args.showHelp();
        return EXIT_SUCCESS;
    }
    if (show_version){
        tool_info() << MODULE_VERSION << std::endl;
        return EXIT_SUCCESS;
    }

    argc -= optind;
    argv += optind;
    
    // Perform the operation 
    int ret = tool_doit(argc, argv);
    return ret;
}
