#!/usr/bin/env python
#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright
# holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# transfer-url-copy test script common functions
#
# Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
# Version info: $Id: Common.py,v 1.3 2008/12/08 12:38:10 ptedesco Exp $
# Release: $Name:  $
import os
import sys
import logging
from stat import *

# Exception classes
#-------------------------------------------------------------------------------
class ScriptException (Exception):
    """Base class for exceptions in this script."""
    
    def __init__(self,msg):
        self.__msg = msg
        
    def __str__(self):
        return self.__msg

# Logging
#-------------------------------------------------------------------------------

# set 'log' as root logger
log = logging.getLogger()

__logging_initialized = False
def InitLogging(path,debug=False):
    """Initialize logging
    path: the log file path. If None, file logging will not be enabled.
    debug: flag to enable debug logging.
    """
    global __logging_initialized
    if __logging_initialized:
        log.error("InitLogging called more than once")
        import pdb; pdb.set_trace()
        return
    __logging_initialized = True

    # get the root logger and set the logging level
    root = logging.getLogger()
    if debug:
        root.setLevel(logging.DEBUG)
    else:
        root.setLevel(logging.INFO)
    
    # log to console
    # set format -> '[level]: message'
    consoleFormatter = logging.Formatter("[%(levelname)s]: %(message)s")
    consoleHander = logging.StreamHandler(sys.stdout)
    consoleHander.setFormatter(consoleFormatter)
    # add handler to root logger
    root.addHandler(consoleHander)
    
    if not path is None:
        # log to file 
        # ensure existence of parent directory
        MakeDir(os.path.dirname(path))
        # set format -> 'timestamp [level]: message'
        fileFormatter = logging.Formatter("%(asctime)s [%(levelname)s]: %(message)s")
        fileHandler = logging.FileHandler(path, "w")
        fileHandler.setFormatter(fileFormatter)
        # add handler to root logger
        root.addHandler(fileHandler)

# File helpers
#-------------------------------------------------------------------------------
def RemoveFile(path):
    """Remove a file."""
    global log
    try:
        log.debug ("removing %s",path)
        os.remove(path)
    except OSError, exc:
        log.error ("removing %s failed: %s",path,str(exc))
        
def MoveFile(src,dest):
    """Move a file.
    Returns the path of the moved file (or the original path if the operation failed).
    src: source file path
    dest: desination file path
    """
    global log
    try:
        log.debug ("moving '%s' -> '%s'",src,dest)
        MakeDir(os.path.dirname(dest))
        os.rename(src,dest)
        return dest
    except OSError, exc:
        log.debug ("moving '%s' -> '%s' failed: %s",src,dest,str(exc))
        return src

def MakeDir(path):
    """Create a directory if it does not exist."""
    global log
    if (not os.path.exists(path)):
        log.debug("creating directory %s",path)
        os.makedirs(path)

def Join(path1,path2):
    """Join two paths, trimming the initial '/'s of the second argument."""
    global log
    while path2[0] == "/":
        path2 = path2[1:len(path2)]
    return os.path.join(path1,path2)

