#!/usr/bin/env python
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# -*- coding: utf-8 -*-
import os
import os.path
import sys
import getopt
from Common import *
import HtmlReport
import TestSet

def print_usage(code = 0):
    print """Usage: %(name)s [options]
Creates an html page with the endpoints definition list.

Options:
  -h, --help : print help message and exit.
  -f, --file : output file name. Default = endpoints.html
""" % {
        "name" : os.path.basename(sys.argv[0])
    }
    sys.exit(code)

def main():
    argv = sys.argv[1:]
    try:
        opts, args = getopt.getopt(argv,"hf:",["help","file"])
    except getopt.GetoptError, err:
        print str(err) # will print something like "option -a not recognized"
        print_usage(-1)
    
    fname = "endpoints.html"

    for opt, arg in opts:
        if opt in ("-h","--help"):
            print_usage()
        elif opt in ("-f","--file"):
            fname = arg
        else:
            print "Invalid option: " + opt
            print_usage(-1)

    if len(args) > 0:
        print_usage(-1)

    ts = TestSet.TestSet()
    ts.initialize()
    page = HtmlReport.HtmlReport.CreateEndpointsPage(ts.Endpoints)
    file = open(fname,'w')
    file.write(str(page))
    file.close()
    print "Endpoints list written to",fname
    return 0

if __name__ == '__main__':
    sys.exit(main())



