#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (c) Members of the EGEE Collaboration. 2004-2008.
# See http://www.eu-egee.org/partners/ for details on the copyright
# holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Utility to create a report from existing test results
#
# Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
# Version info: $Id: create-report.py,v 1.2 2008/12/10 16:13:55 ptedesco Exp $
# Release: $Name:  $
import os
import os.path
import sys
import getopt

from Common import *
import TestSet
import HtmlReport
import Transfers

def print_usage():
    print """Usage: %(name)s config-file YEAR MONTH DAY TIME
Creates an html report from existing results.
""" % {
        "name" : os.path.basename(sys.argv[0])
    }

# create an html report from existing results
def create_report(cfg,year,month,day,time):
    try:
        # create the TestSet object
        ts = TestSet.TestSet(cfg)
        # initialize the endpoints list
        ts.initialize()
        # set the options
        ts.Cfg.TestDateYear = year
        ts.Cfg.TestDateMonth = month
        ts.Cfg.TestDateDay = day
        ts.Cfg.TestDate = year + month + day
        ts.Cfg.TestTime = time
        ts.Cfg.init_params()

        # check directory exists...
        log_dir_path = ts.Cfg.GetLogDirPath()
        print "Checking existence of " + log_dir_path
        if not os.path.exists(log_dir_path):
            raise ScriptException(log_dir_path + " not found")
        
        # determine the list of endpoints
        for endpoint in ts.Endpoints:
            if not endpoint.Excluded:
                ts.AvailableEndpoints.append(endpoint)
        
        def check_log_path(relpath,tx):
            path = Join(relpath,tx.Name)
            path = Join(log_dir_path,path)
            if os.path.exists(path):
                return path
            return None
        
        class FakeProc:
            def __init__(self,logFilePath,logRelDir):
                self.LogFilePath = logFilePath
                self.LogRelDir = logRelDir

        def check_transfer(tx):
            tx.Started = True
            tx.Finished = True
            #determine if it succeeded or failed...
            tx_log_path = check_log_path("completed",tx)
            if tx_log_path != None:
                tx.Succeeded = True
                tx.FailureReason = tx.GetFailureReason(tx_log_path)
                tx._glite_proc = FakeProc(tx_log_path,"completed")
                return True
            else:
                tx_log_path = check_log_path("failed",tx)
                if tx_log_path != None:
                    tx.Succeeded = False
                    tx._glite_proc = FakeProc(tx_log_path,"failed")
                    tx.FailureReason = tx.GetFailureReason(tx_log_path)
                    if None == tx.FailureReason:
                        tx.FailureReason = "failed"
                    return True
                else:
                    return False
            
        #recreate the transfers
        tx_map = {}
        for endpoint in ts.AvailableEndpoints:
            tx_local = Transfers.UrlCopyTransfer(ts.Local,endpoint,"foo","bar")
            if check_transfer(tx_local):
                tx_map[tx_local.Name] = tx_local
            for destination in ts.AvailableEndpoints:
                tx_url = Transfers.UrlCopyTransfer(endpoint,destination,"foo","bar")
                if check_transfer(tx_url):
                    tx_map[tx_url.Name] = tx_url                
                tx_srm_push = Transfers.SrmCopyTransfer(endpoint,destination,True,"foo","bar")
                if check_transfer(tx_srm_push):
                    tx_map[tx_srm_push.Name] = tx_srm_push
                tx_srm_pull = Transfers.SrmCopyTransfer(endpoint,destination,False,"foo","bar")
                if check_transfer(tx_srm_pull):
                    tx_map[tx_srm_pull.Name] = tx_srm_pull
        
        all_endpoints = [ts.Local] + ts.Endpoints

        # create the html report file
        html_report = HtmlReport.HtmlReport(ts.Cfg,ts.Cfg.GetTestDateStr(),all_endpoints,tx_map)
        print "writing to " + ts.Cfg.GetPath("report.html")
        html_report.write(ts.Cfg.GetPath("report.html"))
    except Exception, exc:
        print ("Unexpected exception : " + str(type(exc)) + " args = " + str(exc.args))
        print traceback.format_exc()
        return 1
    
    return 0

def main():
    argv = sys.argv[1:]
    if len(argv) != 5:
        print_usage()
        return 1
    cfg = Configuration.from_file(argv[0])
    year = argv[1]
    month = argv[2]
    day = argv[3]
    time = argv[4]
    return create_report(cfg,year,month,day,time)

if __name__ == '__main__':
    sys.exit(main())



