#!/usr/bin/env python
#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright
# holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# transfer-url-copy test script
#
# Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
# Version info: $Id: transfer-test.py,v 1.4 2009/03/19 13:37:09 molnarzs Exp $
# Release: $Name:  $

import os
import os.path
import sys
import traceback
import shutil
import getopt

from Common import *
import TestSet
import Configuration
import HtmlReport
import UpdateIndex

# run tests
#-------------------------------------------------------------------------------
def run_tests(cfg):
    try:
        # create the TestSet object
        ts = TestSet.TestSet(cfg)
        # initialize the logger
        InitLogging(ts.Cfg.GetTestsLogFilePath(),True)
        # run the tests
        ts.Run()

        all_endpoints = ts.GetAllEndpoints()
        tx_map = ts.GetTxMap()

        # create the html report file
        html_report = HtmlReport.HtmlReport(ts.Cfg,ts.Cfg.GetTestDateStr(),all_endpoints,tx_map)
        html_report.write(ts.Cfg.GetPath("report.html"))
       
        print ("log directory : " + ts.Cfg.GetLogDirPath())
        
        # make a local copy of the index.html file and update it
        local_index = "index.html"
        afs_index = Join(ts.Cfg.AfsPath,"index.html")
        shutil.copy (afs_index,local_index)
        
        UpdateIndex.UpdateIndexFile("index.html",ts.Cfg.GetPathForIndex(),cfg.GetTitle())
        
        # copy the test results and index to /afs
        print "copying index to afs..."
        shutil.copy(local_index,afs_index)
        print "copying files to afs..."
        shutil.copytree(ts.Cfg.GetLogDirPath(),ts.Cfg.GetAfsDestDir())
        
        return 0

    except Exception, exc:
        log.error ("Unexpected exception : " + str(type(exc)) + " args = " + str(exc.args))
        print traceback.format_exc()
        return 1

# print usage
def print_usage(code = 0):
    print """Usage: %(name)s [options] [config-file]
Run the transfer tests

Parameters:
  config-file : file with script configuration parameters.
                If not given, default configuration is used. 

Options:
  -h, --help           : print help message and exit.
  -c, --configuration  : print the default configuration and exit
""" % {
        "name" : os.path.basename(sys.argv[0]),
    }
    sys.exit(code)

# main
#-------------------------------------------------------------------------------
def main():
    argv = sys.argv[1:]
    try:
        opts, args = getopt.getopt(argv,"hc",["help", "configuration"])
    except getopt.GetoptError, err:
        print str(err) # will print something like "option -a not recognized"
        print_usage(-1)
    
    cfg = Configuration.Configuration()
    globals()["options"] = cfg  
    
    for opt, arg in opts:
        if opt in ("-h","--help"):
            print_usage()
        if opt in ("-c", "--configuration"):
            globals()["options"].PrintOptions()
            sys.exit(0)
        else:
            print "Invalid option: " + opt
            print_usage(-1)
    
    if len(args) > 1:
        print "Too many parameters"
        print_usage(-1)

    if len(args) == 1:
        # user specified a configuration file
        config_file = args[0]
        execfile(config_file)

    del globals()["options"]
    run_tests(cfg)

if __name__ == "__main__":
    sys.exit (main())
