#!/bin/bash
#
#  Copyright (c) Members of the EGEE Collaboration. 2004.
#  See http://www.eu-egee.org/partners/ for details on the copyright
#  holders.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#
#  transfer-url-copy test script endpoint variables expansion utilities
#
#  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
#  Version info: $Id: transfer-url-copy-test-endpoints.sh,v 1.4 2007/04/18 07:59:47 ptedesco Exp $
#  Release: $Name:  $

# endpoints number
totalEndpoints=0

#-------------------------------------------------------------------------------
# register an endpoint
#-------------------------------------------------------------------------------
# $1 endpoint name (symbolic name)
# $2 endpoint srm version (1.1 or 2.2)
# $3 host
# $4 port
# $5 service path
# $6 endpoint SAPath
function endpoint ()
{
	if [ 6 -ne ${#} ]; then
		Error "Specify endpoints in the format : \"name\" \"version\" \"host\" \"port\" \"service path\" \"sapath\""
		exit "${E_SCRIPTERR}"
	fi
	_endpointNames[totalEndpoints]=${1}
	_endpointVersions[totalEndpoints]=${2}
	_endpointHosts[totalEndpoints]=${3}
	_endpointPorts[totalEndpoints]=${4}
	_endpointServicePaths[totalEndpoints]=${5}
	_endpointSAPaths[totalEndpoints]=${6}
	(( totalEndpoints++ ))
}

#-------------------------------------------------------------------------------
# include endpoints definitions
#-------------------------------------------------------------------------------
if [ "${endpointsListFile}" ]; then
	# use command line endpoints definition file
	CheckFile "${endpointsListFile}"
	. "${endpointsListFile}"
else
	if [ ${stub} ]; then
		# use stub endpoints definition list
		. stub-endpoints-list.sh		
	else
		# use default endpoints definition list
		. default-endpoints-list.sh
	fi
fi

#-------------------------------------------------------------------------------
# get name for endpoint
#-------------------------------------------------------------------------------
# $1 : endpoint index
function EndpointName ()
{
	CheckParams "EndpointName" 1 ${#}
	echo "${_endpointNames[${1}]}" 
}

#-------------------------------------------------------------------------------
# get address for endpoint
#-------------------------------------------------------------------------------
# $1 : endpoint index
function EndpointAddress ()
{
	CheckParams "EndpointAddress" 1 ${#}
	echo "httpg://${_endpointHosts[${1}]}:${_endpointPorts[${1}]}${_endpointServicePaths[${1}]}" 
}

#-------------------------------------------------------------------------------
# get version for endpoint
#-------------------------------------------------------------------------------
# $1 : endpoint index
function EndpointVersion ()
{
	CheckParams "EndpointVersion" 1 ${#}
	echo "${_endpointVersions[${1}]}" 
}

#-------------------------------------------------------------------------------
# get SAPath for endpoint
#-------------------------------------------------------------------------------
# $1 : endpoint index
function EndpointSAPath ()
{
	CheckParams "EndpointVersion" 1 ${#}
	echo "${_endpointSAPaths[${1}]}" 
}

#-------------------------------------------------------------------------------
# get surl for endpoint and path
#-------------------------------------------------------------------------------
# $1 : endpoint index
# $2 : file path
function Surl ()
{
	CheckParams "Surl" 2 ${#}
	echo "srm://${_endpointHosts[${1}]}:${_endpointPorts[${1}]}${_endpointServicePaths[${1}]}?SFN=`EndpointSAPath ${1}`/${2}"
}

function PrintEndpointsList ()
{
	local i=0
	local ml_name=`expr length name`
	local ml_address=`expr length address`
	local ml_sapath=`expr length sapath`
	for ((i=0;i<totalEndpoints;i++));do
		local ep_name=`EndpointName ${i}`
		if ((${#ep_name} > ${ml_name})); then ml_name=${#ep_name}; fi
		local ep_addr=`EndpointAddress ${i}`
		if ((${#ep_addr} > ${ml_address})); then ml_address=${#ep_addr}; fi
		local ep_sapath=`EndpointSAPath ${i}`
		if ((${#ep_sapath} > ${ml_sapath})); then ml_sapath=${#ep_sapath}; fi
	done
	local header=`printf "index - %-${ml_name}s - ver - %-${ml_address}s - %-${ml_sapath}s - Surl of test file" "name" "address" "SAPath"`
	Info "--------------------------------------------------------------------------------------------------------"
	Info "Endpoints:"
	Info "${header}"
	Info "--------------------------------------------------------------------------------------------------------"
	for ((i=0;i<totalEndpoints;i++));do
		local ep_name=`EndpointName ${i}`
		local ep_ver=`EndpointVersion ${i}`
		local ep_addr=`EndpointAddress ${i}`
		local ep_sapath=`EndpointSAPath ${i}`
		local ep_surl=`Surl ${i} test`
		local epline=`printf "%5s - %-${ml_name}s - %3s - %-${ml_address}s - %-${ml_sapath}s - %s" "${i}" "${ep_name}" "${ep_ver}" "${ep_addr}" "${ep_sapath}" "${ep_surl}"`
		Info "${epline}"
	done
	Info "--------------------------------------------------------------------------------------------------------"
}
PrintEndpointsList
