/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Authors:  Zsolt.Molnar <zsolt.molnar@cern.ch>
 *  
 *  Version info: $Id: test_dao_oracle_TestCase.cpp.tmpl.ftl,v 1.1 2010/02/09 14:31:01 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#include "logger-utility.h"
#include "test-utility.h"

#include "GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files.h"
#include "SrmCopyCoreTestCase_Common.h"

#include <assert.h>

extern std::string g_srm_22_endpoint;

namespace
{
    const char SAMPLE_TEXT[] = "All work and no play makes Jack a dull boy.";
}

namespace glite   {
namespace data    {
namespace transfer{
namespace urlcopy {

void GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files::setUp()
{
    // EMPTY
} 

void GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files::tearDown()
{
    // EMPTY
} 

GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files::PrepareScenario_::PrepareScenario_(SrmCopyCore& self)
    : PrepareDependencies_(self)
{
    // EMPTY
}

GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files::PrepareScenario_::~PrepareScenario_()
{
    // EMPTY
}

bool GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files::PrepareScenario_::pingSource(UrlCopyError::Category&, std::string&)
{
    return true;
}

bool GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files::PrepareScenario_::pingDestination(UrlCopyError::Category&, std::string&)
{
    return true;
}

void GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files::PrepareScenario_::prepareSource()
{
    SrmCopyStat* stat = self_.getStat();
    assert(stat);

    stat->mm_files[0].mm_error.mm_category = UrlCopyError::UrlCopyError::ERROR_LOCALITY;
    stat->mm_files[0].mm_error.mm_scope = UrlCopyError::UrlCopyError::SCOPE_SOURCE;
    stat->mm_files[0].mm_error.mm_phase = UrlCopyError::UrlCopyError::PHASE_PREPARATION;
    stat->mm_files[0].mm_compare_checksum = 1;
}

void GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files::PrepareScenario_::prepareDestination()
{
    // EMPTY
}

void GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files::test()
{
    static const char * test_name = "GGUS58402_FTS_Behaviour_for_UNAVAILABLE_Files";
    static const char * source_file = "srmcopy-locality-UNAVAILABLE-unavailable_01.dat"; 
    static const char * dest_file   = "dest_unavailable_01.dat";

    putFile(source_file, g_srm_22_endpoint, "2.2", SAMPLE_TEXT);

	statSetUpWlcg(
		test_name,
		source_file, "",
		dest_file, "",
		g_srm_22_endpoint, "2.2",
		-1, 0, // copy_pin_lifetime, lan_connection
		1);
    
    SrmCopyCore tx(test_name);
    // Set up the following condition: SOURCE error during PREPARATION phase, because of LOCALITY
    // and turn checksum comparison on.
    PrepareScenario_ prepareScenario(tx);
    tx.prepare_(prepareScenario);
    
    SrmCopyStat* stat = tx.getStat();
    assert(stat);

    CPPUNIT_ASSERT_EQUAL(static_cast<int>(UrlCopyError::UrlCopyError::ERROR_LOCALITY), 
        stat->mm_srmcopy.mm_error.mm_category);

    CPPUNIT_ASSERT_EQUAL(static_cast<int>(UrlCopyError::UrlCopyError::SCOPE_SOURCE), 
        stat->mm_srmcopy.mm_error.mm_scope);

    CPPUNIT_ASSERT_EQUAL(static_cast<int>(UrlCopyError::UrlCopyError::PHASE_PREPARATION), 
        stat->mm_srmcopy.mm_error.mm_phase);
    
    tx.complete();
    // Re-check the error condition. The bug changed the scope/phase of the failure. Check if
    // "complete" did not alter the error data
    CPPUNIT_ASSERT_EQUAL(static_cast<int>(UrlCopyError::UrlCopyError::ERROR_LOCALITY), 
        stat->mm_files[0].mm_error.mm_category);

    CPPUNIT_ASSERT_EQUAL(static_cast<int>(UrlCopyError::UrlCopyError::SCOPE_SOURCE), 
        stat->mm_files[0].mm_error.mm_scope);

    CPPUNIT_ASSERT_EQUAL(static_cast<int>(UrlCopyError::UrlCopyError::PHASE_PREPARATION), 
        stat->mm_files[0].mm_error.mm_phase);
} 

} // end namespace urlcopy
} // end namespace transfer
} // end namespace data
} // end namespace glite

