/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Mmap Test Case
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: MmapTestCase.cpp,v 1.7 2009/03/19 13:37:09 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#include "MmapTestCase.h"

void MmapTestCase::test_SetUp(){
    __TIMER;
    try{
        std::string filename = TransferConfig::instance().repository() + "mmap_unit_test_urlcopy.mem";
        ::unlink(filename.c_str());
    }
    catch(...){
        // Ignore error
    }
    try{
        std::string filename = TransferConfig::instance().repository() + "mmap_unit_test_srmcopy.mem";
        ::unlink(filename.c_str());
    }
    catch(...){
        // Ignore error
    }
}

/*
 * Test Create Method
 */
void MmapTestCase::testCreate_UrlCopy(){
    __TIMER;
    // Create a stat File and return the Mmap object for it
    boost::shared_ptr<Mmap> mmap_ptr = create_stat_UrlCopy("mmap_unit_test_urlcopy");

    // Check Return Value
    CPPUNIT_ASSERT_MESSAGE("Invalid Result" , mmap_ptr.get()     != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Buffer" , mmap_ptr->buffer() != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Size"   , mmap_ptr->size()   != 0);

    // Get the stat object
    UrlCopyStat * stat = reinterpret_cast<UrlCopyStat *>(mmap_ptr->buffer());
    CPPUNIT_ASSERT_MESSAGE("Invalid version"  , stat->mm_common.mm_version   == TRANSFER_STAT_VERSION);
    CPPUNIT_ASSERT_MESSAGE("Invalid extension", stat->mm_common.mm_extension == URLCOPY_STAT_EXTENSION);
    CPPUNIT_ASSERT_MESSAGE("Invalid id"       , stat->mm_common.mm_id        == URLCOPY_STAT_ID);

    // Write something into the buffer
    time(&(stat->mm_common.mm_start_time));
    time(&(stat->mm_common.mm_last_refresh_time));
#ifdef _USE_GLOBAL_TIMEOUT
    stat->mm_common.mm_global_timeout  = 1000;
#endif
    stat->mm_common.mm_flags           = 0xabcd;
    stat->mm_common.mm_overwrite       = 1;
    copy_message(stat->mm_common.mm_dest_token_descr,"description");
}

/*
 * Test Create Method
 */
void MmapTestCase::testCreate_SrmCopy(){
    __TIMER;
    // Create a stat File and return the Mmap object for it
    boost::shared_ptr<Mmap> mmap_ptr = create_stat_SrmCopy("mmap_unit_test_srmcopy",2);

    // Check Return Value
    CPPUNIT_ASSERT_MESSAGE("Invalid Result" , mmap_ptr.get()     != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Buffer" , mmap_ptr->buffer() != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Size"   , mmap_ptr->size()   != 0);

    // Get the stat object
    SrmCopyStat * stat = reinterpret_cast<SrmCopyStat *>(mmap_ptr->buffer());
    CPPUNIT_ASSERT_MESSAGE("Invalid version"  , stat->mm_common.mm_version   == TRANSFER_STAT_VERSION);
    CPPUNIT_ASSERT_MESSAGE("Invalid extension", stat->mm_common.mm_extension == SRMCOPY_STAT_EXTENSION);
    CPPUNIT_ASSERT_MESSAGE("Invalid id"       , stat->mm_common.mm_id        == SRMCOPY_STAT_ID);
    CPPUNIT_ASSERT_MESSAGE("Invalid Num_files", stat->mm_num_files        == 2);

    // Write something into the buffer
    time(&(stat->mm_common.mm_start_time));
    time(&(stat->mm_common.mm_last_refresh_time));
#ifdef _USE_GLOBAL_TIMEOUT
    stat->mm_common.mm_global_timeout  = 1000;
#endif
    stat->mm_common.mm_flags           = 0xabcd;
    stat->mm_common.mm_overwrite       = 1;
    copy_message(stat->mm_common.mm_dest_token_descr,"description");
    stat->mm_files[0].mm_size          = 11111;
    stat->mm_files[1].mm_size          = 22222;
}

/*
 * Test Open Method
 */
void MmapTestCase::testOpen_UrlCopy(){
    __TIMER;
    // Open a stat File and return the Mmap object for it
    boost::shared_ptr<Mmap> mmap_ptr = open_stat_UrlCopy("mmap_unit_test_urlcopy", true);

    // Check Return Value
    CPPUNIT_ASSERT_MESSAGE("Invalid Result" , mmap_ptr.get()     != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Buffer" , mmap_ptr->buffer() != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Size"   , mmap_ptr->size()   != 0);

    // Get the stat object
    UrlCopyStat * stat = reinterpret_cast<UrlCopyStat *>(mmap_ptr->buffer());
    CPPUNIT_ASSERT_MESSAGE("Invalid version"  , stat->mm_common.mm_version   == TRANSFER_STAT_VERSION);
    CPPUNIT_ASSERT_MESSAGE("Invalid extension", stat->mm_common.mm_extension == URLCOPY_STAT_EXTENSION);
    CPPUNIT_ASSERT_MESSAGE("Invalid id"       , stat->mm_common.mm_id        == URLCOPY_STAT_ID);

    // Read what stored in the file
    CPPUNIT_ASSERT_MESSAGE("Invalid start time" , stat->mm_common.mm_start_time        > 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid l.r. time"  , stat->mm_common.mm_last_refresh_time > 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid finish time", stat->mm_common.mm_finish_time      == 0);
#ifdef _USE_GLOBAL_TIMEOUT
    CPPUNIT_ASSERT_MESSAGE("Invalid timeout"    , stat->mm_common.mm_global_timeout   == 1000);
#endif
    CPPUNIT_ASSERT_MESSAGE("Invalid flags"      , stat->mm_common.mm_flags            == 0xabcd);
    CPPUNIT_ASSERT_MESSAGE("Invalid overwrite"  , stat->mm_common.mm_overwrite        == 1);
    CPPUNIT_ASSERT_MESSAGE("Invalid tkn. descr.", strcmp(stat->mm_common.mm_dest_token_descr,"description") == 0);
}

/*
 * Test Open Method
 */
void MmapTestCase::testOpen_SrmCopy(){
    __TIMER;
    // Open a stat File and return the Mmap object for it
    boost::shared_ptr<Mmap> mmap_ptr = open_stat_SrmCopy("mmap_unit_test_srmcopy", true);

    // Check Return Value
    CPPUNIT_ASSERT_MESSAGE("Invalid Result" , mmap_ptr.get()     != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Buffer" , mmap_ptr->buffer() != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Size"   , mmap_ptr->size()   != 0);

    // Get the stat object
    SrmCopyStat * stat = reinterpret_cast<SrmCopyStat *>(mmap_ptr->buffer());
    CPPUNIT_ASSERT_MESSAGE("Invalid version"  , stat->mm_common.mm_version   == TRANSFER_STAT_VERSION);
    CPPUNIT_ASSERT_MESSAGE("Invalid extension", stat->mm_common.mm_extension == SRMCOPY_STAT_EXTENSION);
    CPPUNIT_ASSERT_MESSAGE("Invalid id"       , stat->mm_common.mm_id        == SRMCOPY_STAT_ID);
    CPPUNIT_ASSERT_MESSAGE("Invalid id"       , stat->mm_common.mm_id        == SRMCOPY_STAT_ID);
    CPPUNIT_ASSERT_MESSAGE("Invalid num files", stat->mm_num_files        == 2);

    // Read what stored in the file
    CPPUNIT_ASSERT_MESSAGE("Invalid start time" , stat->mm_common.mm_start_time        > 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid l.r. time"  , stat->mm_common.mm_last_refresh_time > 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid finish time", stat->mm_common.mm_finish_time      == 0);
#ifdef _USE_GLOBAL_TIMEOUT
    CPPUNIT_ASSERT_MESSAGE("Invalid timeout"    , stat->mm_common.mm_global_timeout   == 1000);
#endif
    CPPUNIT_ASSERT_MESSAGE("Invalid flags"      , stat->mm_common.mm_flags            == 0xabcd);
    CPPUNIT_ASSERT_MESSAGE("Invalid overwrite"  , stat->mm_common.mm_overwrite        == 1);
    CPPUNIT_ASSERT_MESSAGE("Invalid tkn. descr.", strcmp(stat->mm_common.mm_dest_token_descr,"description") == 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid file0 size", stat->mm_files[0].mm_size == 11111);
    CPPUNIT_ASSERT_MESSAGE("Invalid file1 size", stat->mm_files[1].mm_size == 22222);
}

/*
 * Test Unlink Method
 */
void MmapTestCase::testUnlink(){
    __TIMER;
    // Open a stat File and return the Mmap object for it
    boost::shared_ptr<Mmap> mmap_ptr = open_stat("mmap_unit_test_urlcopy", true);

    // Check Return Value
    CPPUNIT_ASSERT_MESSAGE("Invalid Result" , mmap_ptr.get()     != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Buffer" , mmap_ptr->buffer() != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Size"   , mmap_ptr->size()   != 0);

    // Close & unlink
    mmap_ptr->close();
    mmap_ptr->unlink();

    std::string filename = TransferConfig::instance().repository() + "mmap_unit_test_urlcopy.mem";
    CPPUNIT_ASSERT_MESSAGE("File Exists"   , 0 != access(filename.c_str(), R_OK));

    // Open a stat File and return the Mmap object for it
    mmap_ptr = open_stat("mmap_unit_test_srmcopy", true);

    // Check Return Value
    CPPUNIT_ASSERT_MESSAGE("Invalid Result" , mmap_ptr.get()     != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Buffer" , mmap_ptr->buffer() != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid Size"   , mmap_ptr->size()   != 0);

    // Close & unlink
    mmap_ptr->close();
    mmap_ptr->unlink();

    filename = TransferConfig::instance().repository() + "mmap_unit_test_srmcopy.mem";
    CPPUNIT_ASSERT_MESSAGE("File Exists"   , 0 != access(filename.c_str(), R_OK));
}
