/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Mmap Test Case
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: MmapTestCase.h,v 1.1 2009/03/19 13:37:09 molnarzs Exp $
 *  Release: $Name:  $
 *
 */

#ifndef TEST_MMAPTESTCASE_H_
#define TEST_MMAPTESTCASE_H_

#include "Mmap.h"
#include "test-utility.h"
#include "stat-utility.h"
#include "TransferConfig.h"
#include <glite/data/agents/AgentExceptions.h>

#include <memory>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <boost/shared_ptr.hpp>

using namespace glite::data::agents;
using namespace glite::data::transfer::urlcopy;

using boost::shared_ptr;

/**
 * CPPUnit TestCase
 */
class MmapTestCase : public CppUnit::TestCase{
private:
    // Declare CPPUnit Methods
    // -------------------------------------------------------------------------
    CPPUNIT_TEST_SUITE( MmapTestCase);
        CPPUNIT_TEST( test_SetUp );
        CPPUNIT_TEST( testCreate_UrlCopy );
        CPPUNIT_TEST( testCreate_SrmCopy );
        CPPUNIT_TEST( testOpen_UrlCopy );
        CPPUNIT_TEST( testOpen_SrmCopy );
        CPPUNIT_TEST( testUnlink );
    CPPUNIT_TEST_SUITE_END();

    // Test Methods
    // -------------------------------------------------------------------------

    /**
     * Test Setup Method
     */
    void test_SetUp();

    /**
     * Test Create Method
     */
    void testCreate_UrlCopy();
    void testCreate_SrmCopy();

    /**
     * Test Open Method
     */
    void testOpen_UrlCopy();
    void testOpen_SrmCopy();

    /**
     * Test Unlink Method
     */
    void testUnlink();

private:
};

#endif // TEST_MMAPTESTCASE_H_
