/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Test cases for Savannah bug #37018.
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: SrmCopyBug_37018.cpp,v 1.1 2009/03/19 13:37:09 molnarzs Exp $
 *  Release: $Name:  $
 *
 */

#include "SrmCopyBug_37018.h"

using namespace glite::data::transfer::urlcopy;

// SRM endpoints
extern std::string g_srm_11_endpoint;
extern std::string g_srm_22_endpoint;

namespace{
    const char SAMPLE_TEXT[] = "All work and no play makes Jack a dull boy.";
}

void SrmCopyBug_37018::bug_setup(
	const char * test_name,
	const char * source_file,
	const char * dest_file,
	int fail_nearline_files)
{
	statSetUpWlcg(
		test_name,
		source_file,"",
		dest_file,"",
		g_srm_22_endpoint,"2.2",
		-1,0, // copy_pin_lifetime, lan_connection
		fail_nearline_files);
}


/**
 * Test that online files always succeed
 */
void SrmCopyBug_37018::online_01()
{
	static const char * test_name   = "SrmCopyBug37018_online_01";
	static const char * source_file = "srmcopy-locality-ONLINE-online_01.dat";
	static const char * dest_file   = "dest_online_01.dat";
	putFile(source_file,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
	bug_setup(test_name,source_file,dest_file,1);
	SrmCopyCore tx(test_name);
	tx.prepare();
	boost::shared_ptr<Mmap> mmap_ptr = open_stat(test_name,true);
	SrmCopyStat * stat = reinterpret_cast<SrmCopyStat *>(mmap_ptr->buffer());
	CPPUNIT_ASSERT_MESSAGE("Invalid stat"   , stat != 0);
	CPPUNIT_ASSERT_MESSAGE("Invalid stat ID", stat->mm_common.mm_id == SRMCOPY_STAT_ID);
	check_status("Invalid Status", stat->mm_srmcopy.mm_status, UrlCopyStatus::READY);
}
/**
 * Test that online files always succeed
 */
void SrmCopyBug_37018::online_02(){
	static const char * test_name   = "SrmCopyBug37018_online_02";
	static const char * source_file = "srmcopy-locality-ONLINE-online_02.dat";
	static const char * dest_file   = "dest_online_02.dat";
	putFile(source_file,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
	bug_setup(test_name,source_file,dest_file,0);
	SrmCopyCore tx(test_name);
	tx.prepare();
	boost::shared_ptr<Mmap> mmap_ptr = open_stat(test_name,true);
	SrmCopyStat * stat = reinterpret_cast<SrmCopyStat *>(mmap_ptr->buffer());
	CPPUNIT_ASSERT_MESSAGE("Invalid stat"   , stat != 0);
	CPPUNIT_ASSERT_MESSAGE("Invalid stat ID", stat->mm_common.mm_id == SRMCOPY_STAT_ID);
	check_status("Invalid Status", stat->mm_srmcopy.mm_status, UrlCopyStatus::READY);
}
/**
 * Test that nearline files fail if the "fail nearline files" option is specified
 */
void SrmCopyBug_37018::nearline_01(){
	static const char * test_name   = "SrmCopyBug37018_nearline_01";
	static const char * source_file = "srmcopy-locality-NEARLINE-nearline_01.dat";
	static const char * dest_file   = "dest_nearline_01.dat";
	putFile(source_file,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
	bug_setup(test_name,source_file,dest_file,1);
	SrmCopyCore tx(test_name);
	tx.prepare();
	boost::shared_ptr<Mmap> mmap_ptr = open_stat(test_name,true);
	SrmCopyStat * stat = reinterpret_cast<SrmCopyStat *>(mmap_ptr->buffer());
	CPPUNIT_ASSERT_MESSAGE("Invalid stat"   , stat != 0);
	CPPUNIT_ASSERT_MESSAGE("Invalid stat ID", stat->mm_common.mm_id == SRMCOPY_STAT_ID);
	check_status("Invalid Status", stat->mm_srmcopy.mm_status, UrlCopyStatus::PREPARING);

	check_scope("Invalid Scope", stat->mm_srmcopy.mm_error.mm_scope, UrlCopyError::SCOPE_SOURCE);
	check_phase("Invalid Phase", stat->mm_srmcopy.mm_error.mm_phase, UrlCopyError::PHASE_PREPARATION);
	check_category("Invalid Error", stat->mm_srmcopy.mm_error.mm_category, UrlCopyError::ERROR_LOCALITY);
}
/**
 * Test that nearline files succeed if the "fail nearline files" option is not specified
 */
void SrmCopyBug_37018::nearline_02(){
	static const char * test_name   = "SrmCopyBug37018_nearline_02";
	static const char * source_file = "srmcopy-locality-NEARLINE-nearline_02.dat";
	static const char * dest_file   = "dest_nearline_02.dat";
	putFile(source_file,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
	bug_setup(test_name,source_file,dest_file,0);
	SrmCopyCore tx(test_name);
	tx.prepare();
	boost::shared_ptr<Mmap> mmap_ptr = open_stat(test_name,true);
	SrmCopyStat * stat = reinterpret_cast<SrmCopyStat *>(mmap_ptr->buffer());
	CPPUNIT_ASSERT_MESSAGE("Invalid stat"   , stat != 0);
	CPPUNIT_ASSERT_MESSAGE("Invalid stat ID", stat->mm_common.mm_id == SRMCOPY_STAT_ID);
	check_status("Invalid Status", stat->mm_srmcopy.mm_status, UrlCopyStatus::READY);
}
