/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: SrmCopyCoreTokens Test Case
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: SrmCopyCoreCheckSumTestCase.h,v 1.2 2009/07/30 19:32:55 molnarzs Exp $
 *  Release: $Name:  $
 *
 */

#ifndef TEST_SRMCOPYCORECHECKSUMTESTCASE_H_
#define TEST_SRMCOPYCORECHECKSUMTESTCASE_H_

#include "SrmCopyCore.h"
#include "test-utility.h"
#include "Mmap.h"
#include "stat-utility.h"
#include "TransferConfig.h"
#include <glite/data/agents/AgentExceptions.h>

#include <glite/data/srm/util/Context.h>
#include <glite/data/srm/util/PrepareToPut.h>
#include <glite/data/srm/util/SrmMkDir.h>

#include <memory>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <boost/shared_ptr.hpp>
#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>

#include "SrmCopyCoreTestCase_Common.h"

using namespace glite::data::agents;
using namespace glite::data::srm::util;
using namespace glite::data::transfer::urlcopy;

using boost::shared_ptr;

/**
 * CPPUnit TestCase
 */
class SrmCopyCoreCheckSumTestCase :
    public SrmCopyCoreTestCase_Common,
    public CppUnit::TestCase{
private:
    // Declare CPPUnit Methods
    // -------------------------------------------------------------------------
    CPPUNIT_TEST_SUITE( SrmCopyCoreCheckSumTestCase );
        CPPUNIT_TEST( test_setup );
        CPPUNIT_TEST(testUseCase0);
        CPPUNIT_TEST(testUseCase1_src_dst_checksumMatch);
        CPPUNIT_TEST(testUseCase1_src_checksumNotAvailable);
        CPPUNIT_TEST(testUseCase1_src_checksumDifferent);
        CPPUNIT_TEST(testUseCase1_dst_gridFTPfallback);
        CPPUNIT_TEST(testUseCase1_dst_checksumNotAvailable);
        CPPUNIT_TEST(testUseCase1_dst_checksumDifferent);
    CPPUNIT_TEST_SUITE_END();

    // Test Methods
    // -------------------------------------------------------------------------

    /**
     * tests for checksum handling
     */
    void test_setup();

    /**
     * User does not provide checksum, comparison not required.
     */
    void testUseCase0();

    /**
     * Use case 1
     * Source/destination checksum is available from SrmLs and matches.
     */
    void testUseCase1_src_dst_checksumMatch();

    /**
     * Use case 1
     * Source checksum is not available from SrmLs - do not fall back to gridFTP
     */
    void testUseCase1_src_checksumNotAvailable();

    /**
     * Use case 1
     * Source checksum is available, but different. The test retrieves it from the SrmLs, no
     * explicit test for wrong checksum returned from gridFTP (the comparison code to be tested
     * is shared).
     */
    void testUseCase1_src_checksumDifferent();

    /**
     * Use case 1
     * Source checksum is OK, destination checksum is not available from srmLs, fallback to gridftp.
     */
    void testUseCase1_dst_gridFTPfallback();

    /**
     * Use case 1
     * Source checksum is OK, destination checksum is not available. Should be CHECKSUM_MISMATCH
     * error in the FINALIZATION/DESTINATION.
     */
    void testUseCase1_dst_checksumNotAvailable();

    /**
     * Use case 1
	 * Destination checksum different
     */
    void testUseCase1_dst_checksumDifferent();
};

#endif // TEST_SRMCOPYCORECHECKSUMTESTCASE_H_
