/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: SrmCopyCore Test Case
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: SrmCopyCoreTestCase.cpp,v 1.15 2009/03/19 13:37:09 molnarzs Exp $
 *  Release: $Name:  $
 *
 */

#include "SrmCopyCoreTestCase.h"

/*
 * The SRM endpoints
 */
extern std::string g_srm_11_endpoint;
extern std::string g_srm_22_endpoint;

namespace {
const char SAMPLE_TEXT[] = "Hello World! This is a test\nWrite some data for Transfer Srm Copy tests\n";
const char EMPTY_FILE[] = "";
}

/*
 * Put Source file for 1.1 tests
 */
void SrmCopyCoreTestCase::test_PutSource_11(){
    __TIMER;
    CPPUNIT_ASSERT_MESSAGE("Invalid Endpoint", g_srm_11_endpoint.empty() == false);
    putFile("srmcopycore_001.dat",g_srm_11_endpoint,"1.1",SAMPLE_TEXT);
    putFile("srmcopycore_002.dat",g_srm_11_endpoint,"1.1",SAMPLE_TEXT);
}

/*
 * Put Source file for 2.2 tests
 */
void SrmCopyCoreTestCase::test_PutSource_22(){
    __TIMER;
    CPPUNIT_ASSERT_MESSAGE("Invalid Endpoint", g_srm_22_endpoint.empty() == false);
    putFile("srmcopycore_001.dat",g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
    putFile("srmcopycore_002.dat",g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
}


/*
 * Test SetUp
 */
void SrmCopyCoreTestCase::test_SetUp_11(){
    __TIMER;
    statSetUp("srmcopycore_unit_test_11","srmcopycore_001.dat","srmcopycore_002.dat","srmcopycore_101.dat","srmcopycore_102.dat",g_srm_11_endpoint,"1.1");
}

/*
 * Test SetUp
 */
void SrmCopyCoreTestCase::test_SetUp_22(){
    __TIMER;
    statSetUp("srmcopycore_unit_test_22","srmcopycore_001.dat","srmcopycore_002.dat","srmcopycore_101.dat","srmcopycore_102.dat",g_srm_22_endpoint,"2.2");
}

/*
 * Test Prepare Method
 */
void SrmCopyCoreTestCase::testPrepare_11(){
    __TIMER;
    prepare("srmcopycore_unit_test_11");
}

/*
 * Test Prepare Method
 */
void SrmCopyCoreTestCase::testPrepare_22(){
    __TIMER;
    prepare("srmcopycore_unit_test_22");
}

/*
 * Test Transfer Method
 */
void SrmCopyCoreTestCase::testTransfer_11(){
    __TIMER;
    transfer("srmcopycore_unit_test_11");
}

/*
 * Test Transfer Method
 */
void SrmCopyCoreTestCase::testTransfer_22(){
    __TIMER;
    transfer("srmcopycore_unit_test_22");
}

/*
 * Test Complete Method
 */
void SrmCopyCoreTestCase::testComplete_11(){
    __TIMER;
    complete("srmcopycore_unit_test_11");
}

/*
 * Test Complete Method
 */
void SrmCopyCoreTestCase::testComplete_22(){
    __TIMER;
    complete("srmcopycore_unit_test_22");
}

/**
 * test case of source SRM returning 0 length in prepareToGet
 */
static const char * zero_lenPtg_file_1      = "srmcopycore-this-one-returns-size-zero-on-get.dat";
static const char * zero_lenPtg_file_2      = "srmcopycore-also-this-one-returns-size-zero-on-get.dat";
static const char * zero_lenPtg_file_dest_1 = "srmcopycore-copy-of-this-one-returns-size-zero-on-get.dat";
static const char * zero_lenPtg_file_dest_2 = "srmcopycore-copy-of-also-this-one-returns-size-zero-on-get.dat";

void SrmCopyCoreTestCase::test_0LenPtg_11(){
    __TIMER;
    static const char * test_name = "srmcopycore_unit_test_0LenPtg_11";
    CPPUNIT_ASSERT_MESSAGE("Invalid Endpoint", g_srm_11_endpoint.empty() == false);
    putFile(zero_lenPtg_file_1,g_srm_11_endpoint,"1.1",SAMPLE_TEXT);
    putFile(zero_lenPtg_file_2,g_srm_11_endpoint,"1.1",SAMPLE_TEXT);
    statSetUp(test_name,zero_lenPtg_file_1,zero_lenPtg_file_2,zero_lenPtg_file_dest_1,zero_lenPtg_file_dest_2,g_srm_11_endpoint,"1.1");
    prepare(test_name);
    transfer(test_name);
    complete(test_name);
}
void SrmCopyCoreTestCase::test_0LenPtg_22(){
    __TIMER;
    static const char * test_name = "srmcopycore_unit_test_0LenPtg_22";
    CPPUNIT_ASSERT_MESSAGE("Invalid Endpoint", g_srm_22_endpoint.empty() == false);
    putFile(zero_lenPtg_file_1,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
    putFile(zero_lenPtg_file_2,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
    statSetUp(test_name,zero_lenPtg_file_1,zero_lenPtg_file_2,zero_lenPtg_file_dest_1,zero_lenPtg_file_dest_2,g_srm_22_endpoint,"2.2");
    prepare(test_name);
    transfer(test_name);
    complete(test_name);
}

static const char * srmCopyMkDir_source_1 = "srmcopycore-mkdirtest_1.dat";
static const char * srmCopyMkDir_source_2 = "srmcopycore-mkdirtest_2.dat";
static const char * srmCopyMkDir_dest_1   = "dirtest/one/two/three/srmcopycore-mkdirtest_1.dat";
static const char * srmCopyMkDir_dest_2   = "dirtest/one/two/three/srmcopycore-mkdirtest_2.dat";
void SrmCopyCoreTestCase::test_srmCopyMkDir(){
    __TIMER;
    static const char * test_name = "srmcopycore_unit_test_rmCopyMkDir";
    CPPUNIT_ASSERT_MESSAGE("Invalid Endpoint", g_srm_22_endpoint.empty() == false);
    putFile(srmCopyMkDir_source_1,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
    putFile(srmCopyMkDir_source_2,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
    statSetUp(test_name,srmCopyMkDir_source_1,srmCopyMkDir_source_2,srmCopyMkDir_dest_1,srmCopyMkDir_dest_2,g_srm_22_endpoint,"2.2");
    prepare(test_name);
    transfer(test_name);
    complete(test_name);
}

void SrmCopyCoreTestCase::test_srmCopyFilesStatus(){
    __TIMER;

    static const char * source_1 = "source_1.dat";
    static const char * source_2 = "this-one-returns-SRM_DUPLICATION_ERROR-on-copy.dat";

    static const char * dest_1 = "dest_1.dat";
    static const char * dest_2 = "dest_2.dat";

    static const char * test_name = "srmcopycore_unit_test_srmCopyFilesStatus";

    putFile(source_1,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
    putFile(source_2,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
    statSetUp(test_name,source_1,source_2,dest_1,dest_2,g_srm_22_endpoint,"2.2");
    prepare(test_name);


    {
    // Create Tx Core Object
    SrmCopyCore tx(test_name);
    // Prepare For transfer
    tx.transfer();
    }

    boost::shared_ptr<Mmap> mmap_ptr = open_stat(test_name,true);

    // Get the stat object
    SrmCopyStat * stat = reinterpret_cast<SrmCopyStat *>(mmap_ptr->buffer());
    CPPUNIT_ASSERT_MESSAGE("Invalid stat"   , stat != 0);
    CPPUNIT_ASSERT_MESSAGE("Invalid stat id", stat->mm_common.mm_id == SRMCOPY_STAT_ID);
}
