/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: SrmCopyCore Test Case
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: SrmCopyCoreTestCase.h,v 1.1 2009/03/19 13:37:09 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#ifndef TEST_SRMCOPYCORETESTCASE_H_
#define TEST_SRMCOPYCORETESTCASE_H_

#include "SrmCopyCore.h"
#include "test-utility.h"
#include "Mmap.h"
#include "stat-utility.h"
#include "TransferConfig.h"
#include <glite/data/agents/AgentExceptions.h>

#include <glite/data/srm/util/Context.h>
#include <glite/data/srm/util/PrepareToPut.h>
#include <glite/data/srm/util/SrmMkDir.h>

#include <memory>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <boost/shared_ptr.hpp>
#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>

#include "SrmCopyCoreTestCase_Common.h"

using namespace glite::data::agents;
using namespace glite::data::srm::util;
using namespace glite::data::transfer::urlcopy;

using boost::shared_ptr;

/**
 * CPPUnit TestCase
 */
class SrmCopyCoreTestCase :
    public SrmCopyCoreTestCase_Common,
    public CppUnit::TestCase{
private:
    // Declare CPPUnit Methods
    // -------------------------------------------------------------------------
    CPPUNIT_TEST_SUITE( SrmCopyCoreTestCase );
        // 1.1 Test
        CPPUNIT_TEST( test_PutSource_11 );
        CPPUNIT_TEST( test_SetUp_11 );
        CPPUNIT_TEST( testPrepare_11 );
        CPPUNIT_TEST( testTransfer_11 );
        CPPUNIT_TEST( testComplete_11 );
        // 2.2 Test
        CPPUNIT_TEST( test_PutSource_22 );
        CPPUNIT_TEST( test_SetUp_22 );
        CPPUNIT_TEST( testPrepare_22 );
        CPPUNIT_TEST( testTransfer_22 );
        CPPUNIT_TEST( testComplete_22 );
        // specific cases
        CPPUNIT_TEST( test_0LenPtg_11 );
        CPPUNIT_TEST( test_0LenPtg_22 );
        CPPUNIT_TEST( test_srmCopyMkDir );
        CPPUNIT_TEST( test_srmCopyFilesStatus );
    CPPUNIT_TEST_SUITE_END();
    // Test Methods
    // -------------------------------------------------------------------------

    /**
     * Test Setup for SRM 1.1
     */
    void test_PutSource_11();
    void test_PutSource_22();
    void test_SetUp_11();
    void test_SetUp_22();

    /**
     * Test Prepare Method
     */
    void testPrepare_11();
    void testPrepare_22();

    /**
     * Test Transfer Method
     */
    void testTransfer_11();
    void testTransfer_22();

    /**
     * Test Complete Method
     */
    void testComplete_11();
    void testComplete_22();

    /**
     * test case of source SRM returning 0 length in prepareToGet
     */
    void test_0LenPtg_11();
    void test_0LenPtg_22();

    /**
     * test case for preparation of target directory in srmCopy operations
     * (bug 28583)
     */
    void test_srmCopyMkDir();

    void test_srmCopyFilesStatus();

};

#endif // TEST_SRMCOPYCORETESTCASE_H_
