/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: SrmCopyCore Test Case
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: SrmCopyCoreTestCase_Common.h,v 1.3 2009/07/30 19:32:55 molnarzs Exp $
 *  Release: $Name:  $
 *
 */

#ifndef TEST_SRMCOPYCORETESTCASE_COMMON_H_
#define TEST_SRMCOPYCORETESTCASE_COMMON_H_

#include <string>

class SrmCopyCoreTestCase_Common{
protected:

    /**
     * Setup stat file for the tests
     */
    void statSetUp(
        const std::string&  name,
        const std::string&  src_name_1,
        const std::string&  src_name_2,
        const std::string&  dst_name_1,
        const std::string&  dst_name_2,
        const std::string&  endpoint,
        const std::string&  version);

    void statSetUpWithTokens(
        const std::string&  name,
        const std::string&  src_name_1,
        const std::string&  src_name_2,
        const std::string&  dst_name_1,
        const std::string&  dst_name_2,
        const std::string&  endpoint,
        const std::string&  version,
        const std::string&  source_space_token,
        const std::string&  dest_space_token);

    void statSetUpWlcg(
        const std::string&  name,
        const std::string&  src_name_1,
        const std::string&  src_name_2,
        const std::string&  dst_name_1,
        const std::string&  dst_name_2,
        const std::string&  endpoint,
        const std::string&  version,
        int                 copy_pin_lifetime,
        int                 lan_connection,
        int                 fail_nearline_files);

    void statSetUpCksm(
        const std::string&  name,
        const std::string&  src_name_1,
        const std::string&  src_name_2,
        const std::string&  dst_name_1,
        const std::string&  dst_name_2,
        const std::string&  endpoint,
        const std::string&  version,
        const std::string&  algorithm_1,
        const std::string&  value_1,
        const std::string&  algorithm_2,
        const std::string&  value_2,
        const int compare = 1);

    /**
     * Call prepare
     */
    void prepare(const std::string& name);
    /**
     * Call transfer
     */
    void transfer(const std::string& name);
    /**
     * Call complete
     */
    void complete(const std::string& name);
};

#endif // TEST_SRMCOPYCORETESTCASE_COMMON_H_

