/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: SrmCopyCoreTokens Test Case
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: SrmCopyCoreTokensTestCase.h,v 1.1 2009/03/19 13:37:09 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#ifndef TEST_SRMCOPYCORETOKENSTESTCASE_H_
#define TEST_SRMCOPYCORETOKENSTESTCASE_H_

#include "SrmCopyCore.h"
#include "test-utility.h"
#include "Mmap.h"
#include "stat-utility.h"
#include "TransferConfig.h"
#include <glite/data/agents/AgentExceptions.h>

#include <glite/data/srm/util/Context.h>
#include <glite/data/srm/util/PrepareToPut.h>
#include <glite/data/srm/util/SrmMkDir.h>

#include <memory>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <boost/shared_ptr.hpp>
#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>

#include "SrmCopyCoreTestCase_Common.h"

using namespace glite::data::agents;
using namespace glite::data::srm::util;
using namespace glite::data::transfer::urlcopy;

using boost::shared_ptr;

/**
 * CPPUnit TestCase
 */
class SrmCopyCoreTokensTestCase :
    public SrmCopyCoreTestCase_Common,
    public CppUnit::TestCase{
private:
    // Declare CPPUnit Methods
    // -------------------------------------------------------------------------
    CPPUNIT_TEST_SUITE( SrmCopyCoreTokensTestCase );
        CPPUNIT_TEST( test_space_token_setup );
        CPPUNIT_TEST( test_space_token_01 );
        CPPUNIT_TEST( test_space_token_02 );
        CPPUNIT_TEST( test_space_token_03 );
        CPPUNIT_TEST( test_space_token_04 );
        CPPUNIT_TEST( test_space_token_05 );
        CPPUNIT_TEST( test_space_token_06 );
    CPPUNIT_TEST_SUITE_END();

    // Test Methods
    // -------------------------------------------------------------------------

    /**
     * tests for space tokens handling
     */
    void test_space_token_setup();
    void test_space_token_01();
    void test_space_token_02();
    void test_space_token_03();
    void test_space_token_04();
    void test_space_token_05();
    void test_space_token_06();

};

#endif // TEST_SRMCOPYCORETOKENSTESTCASE_H_
