/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Test classes for Savannah bug ##58470:
 *      FTS: make syslog facility configurable.
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch>
 *
 *  Version info: $Id: Test58470_MakeSyslogConfigurable.cpp,v 1.1 2009/12/03 17:21:45 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#include "Test58470_MakeSyslogConfigurable.h"
#include "test-utility.h"
#include "glite/data/transfer/urlcopy/TransferUrlCopy.h"
#include <glite/data/config/service/SysLogDaemon.h>
#include <glite/data/config/service/SysLogInfo.h>
#include <syslog.h>
#include <unistd.h>

using namespace glite::data::transfer::urlcopy;
using namespace glite::config;

void Test58470_MakeSyslogConfigurable::testSyslogGetsConfiguredFromArgs()
{
    CPPUNIT_ASSERT(LOG_USER != SysLogInfo::instance().getFacility());
    // Create the args structure
    TransferUrlCopy::Args args;
    args.syslog_disable = false;
    args.syslog_facility = LOG_USER;
    args.syslog_facility_name = "LOG_USER";
    args.syslog_ident = "syslog-test";
    // Pass it to transfer-url-copy
    TransferUrlCopy::Ptr tx = TransferUrlCopy::start(args, "", true);
    // Check the content of SysLogInfo (if it was parametrized)
    CPPUNIT_ASSERT_EQUAL(LOG_USER, SysLogInfo::instance().getFacility());
    CPPUNIT_ASSERT_EQUAL(std::string("LOG_USER"), SysLogInfo::instance().getFacilityName());
    CPPUNIT_ASSERT_EQUAL(std::string("syslog-test"), SysLogInfo::instance().getIdent());
    SysLogDaemon(true).add("SYSLOG_DISABLE", "FALSE").info();
}

void Test58470_MakeSyslogConfigurable::testEnableDisableSyslog()
{
    // TODO automate this part...
    // This part of the unit test is tricky, because it involves writing into
    // the syslog. What you need to do:
    //
    // 1. Write the following (or similar...) line to /etc/syslog.conf:
    //
    // user.* /tmp/test.log
    //
    // After running the unit tests, analyze the content. The file must contain
    // a line that contains "SYSLOG_DISABLE=FALSE" and must not contain line
    // containing "SYSLOG_DISABLE=TRUE".
    // Ensure that your syslog daemon has been started.
    //
    // One more thing... You need to run the tests twice, when only one of the
    // test functions is enabled, because the logger cannot be reconfigured
    // in a process, once it got configured.
    TransferUrlCopy::Args args;
    args.syslog_disable = true;
    args.syslog_facility = LOG_USER;
    args.syslog_facility_name = "LOG_USER";
    args.syslog_ident = "syslog-test";
    TransferUrlCopy::Ptr tx = TransferUrlCopy::start(args, "", true);
    SysLogDaemon(true).add("SYSLOG_DISABLE", "TRUE").info();
}
