/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Transfer Structs Test Case
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: TransferStructsTestCase.cpp,v 1.13 2009/07/02 15:02:09 molnarzs Exp $
 *  Release: $Name:  $
 *
 */

#include "TransferStructsTestCase.h"

template <typename T1,typename T2>
bool compare(T1 t1,T2 t2){
    return (t1 == (T1)t2);
}
bool compare_strings(std::string s1,std::string s2){
    return (s1 == s2);
}

#define _URLCOPY_ARGS_TO_URLCOPYSTAT(args_property,args_property_value,stat_property,stat_property_expected,comp_fn) \
    try{ \
        TransferUrlCopy::Args args; \
        args.args_property = args_property_value; \
        UrlCopyStat stat ; \
        transferUrlCopyArgs_to_UrlCopyStat(args,stat); \
        if (!comp_fn(stat.stat_property,stat_property_expected)) { \
            std::stringstream error; \
            error << "Error converting TransferUrlCopy::Args::" << #args_property; \
            error << " to UrlCopyStat::" << #stat_property << ". Got value '" << stat.stat_property; \
            error << "' expected '" << stat_property_expected << "'";\
            CPPUNIT_FAIL(error.str().c_str());\
        } \
    } catch(const std::exception& exc){ \
        CPPUNIT_FAIL(exc.what()); \
    } catch(...){ \
        CPPUNIT_FAIL("Got Unknown Error"); \
    }

// use this version to compare different types (bool, unsigned int)
#define URLCOPY_ARGS_TO_URLCOPYSTAT_D(args_property,args_property_value,stat_property,stat_property_expected) \
    _URLCOPY_ARGS_TO_URLCOPYSTAT(args_property,args_property_value,stat_property,stat_property_expected,compare)

// use this version to compare strings
#define URLCOPY_ARGS_TO_URLCOPYSTAT_S(args_property,stat_property,value) \
    _URLCOPY_ARGS_TO_URLCOPYSTAT(args_property,value,stat_property,value,compare_strings)

// use this version to compare equal types
#define URLCOPY_ARGS_TO_URLCOPYSTAT_V(args_property,stat_property,value) \
    _URLCOPY_ARGS_TO_URLCOPYSTAT(args_property,value,stat_property,value,compare)

/**
 * check the conversion from UrlCopy::Args class to UrlCopyStat structure
 */
void TransferStructsTestCase::urlcopy_args_to_urlcopystat(){
    __TIMER;
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(overwrite,false,mm_common.mm_overwrite,0);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(overwrite,true,mm_common.mm_overwrite,1);

    URLCOPY_ARGS_TO_URLCOPYSTAT_D(verbose,false,mm_common.mm_verbose,0);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(verbose,true,mm_common.mm_verbose,1);

    URLCOPY_ARGS_TO_URLCOPYSTAT_S(dest_space_token, mm_common.mm_dest_space_token,    "token");
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(dest_token_descr, mm_common.mm_dest_token_descr,    "token_descr");
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(user_tag,         mm_common.mm_user_tag,            "user_tag");

    // Source File
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(src_endpoint, mm_urlcopy.mm_source.mm_srm_endpoint,    "source_endpoint");
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(src_version,  mm_urlcopy.mm_source.mm_srm_version,     "2.2");
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(src_name,     mm_urlcopy.mm_source.mm_name,            "source_name");

    URLCOPY_ARGS_TO_URLCOPYSTAT_V(http_timeout,     mm_urlcopy.mm_source.mm_http_timeout,    1);
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(get_timeout,      mm_urlcopy.mm_source.mm_prep_timeout,    2);
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(getdone_timeout,  mm_urlcopy.mm_source.mm_final_timeout,   3);

    // Destination File
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(dest_endpoint, mm_urlcopy.mm_destination.mm_srm_endpoint,    "dest_endpoint");
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(dest_version,  mm_urlcopy.mm_destination.mm_srm_version,     "1.1");
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(dest_name,     mm_urlcopy.mm_destination.mm_name,            "dest_name");

    URLCOPY_ARGS_TO_URLCOPYSTAT_V(http_timeout,     mm_urlcopy.mm_destination.mm_http_timeout,    4);
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(put_timeout,      mm_urlcopy.mm_destination.mm_prep_timeout,    5);
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(putdone_timeout,  mm_urlcopy.mm_destination.mm_final_timeout,   6);

    // Transfer
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(nstreams,mm_urlcopy.mm_tx.mm_streams,7);
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(tcpbs,mm_urlcopy.mm_tx.mm_tcp_bs,8);
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(blocksize,mm_urlcopy.mm_tx.mm_block_size,9);
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(tx_timeout,mm_urlcopy.mm_tx.mm_timeout,10);
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(tx_markers_timeout,mm_urlcopy.mm_tx.mm_marker_timeout,11);

}

/**
 * urlcopy_args_to_urlcopystat_310
 */
void TransferStructsTestCase::urlcopy_args_to_urlcopystat_310(){
    __TIMER;
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(source_space_token, mm_common.mm_source_space_token,    "token");
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(source_token_descr, mm_common.mm_source_token_descr,    "token_descr");

    URLCOPY_ARGS_TO_URLCOPYSTAT_D(enable_dir_check,false,mm_common.mm_enable_dir_check,0);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(enable_dir_check,true,mm_common.mm_enable_dir_check,1);

    URLCOPY_ARGS_TO_URLCOPYSTAT_D(enable_ping_source,false,mm_common.mm_enable_ping_source,0);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(enable_ping_source,true,mm_common.mm_enable_ping_source,1);

    URLCOPY_ARGS_TO_URLCOPYSTAT_D(enable_ping_dest,false,mm_common.mm_enable_ping_dest,0);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(enable_ping_dest,true,mm_common.mm_enable_ping_dest,1);

    URLCOPY_ARGS_TO_URLCOPYSTAT_V(first_tx_marker_timeout,mm_urlcopy.mm_tx.mm_first_marker_timeout,12);
}

/**
 * urlcopy_args_to_urlcopystat_320
 */
void TransferStructsTestCase::urlcopy_args_to_urlcopystat_320(){
    __TIMER;
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(block_after_preparation,false,mm_common.mm_block_after_preparation,0);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(block_after_preparation,true,mm_common.mm_block_after_preparation,1);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(block_after_transfer,false,mm_common.mm_block_after_transfer,0);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(block_after_transfer,true,mm_common.mm_block_after_transfer,1);
}

/**
 * urlcopy_args_to_urlcopystat_330
 */
void TransferStructsTestCase::urlcopy_args_to_urlcopystat_330(){
    __TIMER;
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(copy_pin_lifetime,mm_common.mm_copy_pin_lifetime,1250);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(lan_connection,false,mm_common.mm_lan_connection,0);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(lan_connection,true,mm_common.mm_lan_connection,1);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(fail_nearline_files,false,mm_common.mm_fail_nearline_files,0);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(fail_nearline_files,true,mm_common.mm_fail_nearline_files,1);
}

/**
 * urlcopy_args_to_urlcopystat_340
 */
void TransferStructsTestCase::urlcopy_args_to_urlcopystat_340(){
    __TIMER;
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(no_progress_timeout,mm_urlcopy.mm_tx.mm_no_progress_timeout,555);
    URLCOPY_ARGS_TO_URLCOPYSTAT_V(tx_to_per_mb,mm_urlcopy.mm_tx.mm_tx_to_per_mb,5.55);
}

/**
 * urlcopy_args_to_urlcopystat_350
 */
void TransferStructsTestCase::urlcopy_args_to_urlcopystat_350(){
    __TIMER;
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(compare_checksum,false,mm_urlcopy.mm_compare_checksum,0);
    URLCOPY_ARGS_TO_URLCOPYSTAT_D(compare_checksum,true,mm_urlcopy.mm_compare_checksum,1);
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(checksum_user_algorithm,mm_urlcopy.mm_checksum_user_algorithm,"FOOBAR32");
    URLCOPY_ARGS_TO_URLCOPYSTAT_S(checksum_user_value,mm_urlcopy.mm_checksum_user_value,"c0ffee"); // an hex string
}

#define _SRMCOPY_ARGS_TO_SRMCOPYSTAT(args_property,args_property_value,stat_property,stat_property_expected,comp_fn) \
    try{ \
        TransferSrmCopy::Args args; \
        args.args_property = args_property_value; \
        SrmCopyStat stat; \
        transferSrmCopyArgs_to_SrmCopyStat(args,stat); \
        if (!comp_fn(stat.stat_property,stat_property_expected)) { \
            std::stringstream error; \
            error << "Error converting TransferSrmCopy::Args::" << #args_property; \
            error << " to SrmCopyStat::" << #stat_property << ". Got value '" << stat.stat_property; \
            error << "' expected '" << stat_property_expected << "'";\
            CPPUNIT_FAIL(error.str().c_str());\
        } \
    } catch(const std::exception& exc){ \
        CPPUNIT_FAIL(exc.what()); \
    } catch(...){ \
        CPPUNIT_FAIL("Got Unknown Error"); \
    }

// use this version to compare different types (bool, unsigned int)
#define SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(args_property,args_property_value,stat_property,stat_property_expected) \
    _SRMCOPY_ARGS_TO_SRMCOPYSTAT(args_property,args_property_value,stat_property,stat_property_expected,compare)

// use this version to compare strings
#define SRMCOPY_ARGS_TO_SRMCOPYSTAT_S(args_property,stat_property,value) \
    _SRMCOPY_ARGS_TO_SRMCOPYSTAT(args_property,value,stat_property,value,compare_strings)

// use this version to compare equal types
#define SRMCOPY_ARGS_TO_SRMCOPYSTAT_V(args_property,stat_property,value) \
    _SRMCOPY_ARGS_TO_SRMCOPYSTAT(args_property,value,stat_property,value,compare)

#define _SRMCOPY_FILEARGS_TO_SRMCOPYSTAT(args_property,args_property_value,stat_property,stat_property_expected,comp_fn) \
    try{ \
        char buffer[sizeof(SrmCopyStat) + sizeof(SrmCopy_FileStat)];\
        memset(buffer,0,sizeof(SrmCopyStat) + sizeof(SrmCopy_FileStat));\
        TransferSrmCopy::Args args; \
        details::SurlPair f; \
        f.args_property = args_property_value; \
        args.files.push_back(f); \
        SrmCopyStat * stat = reinterpret_cast<SrmCopyStat*>(buffer);\
        stat->mm_num_files = 1;\
        transferSrmCopyArgs_to_SrmCopyStat(args,*stat); \
        if (!comp_fn(stat->mm_files[0].stat_property,stat_property_expected)) { \
            std::stringstream error; \
            error << "Error converting TransferSrmCopy::Args::File::" << #args_property; \
            error << " to SrmCopyStat::SrmCopy_FileStat" << #stat_property << ". Got value '" << stat->mm_files[0].stat_property; \
            error << "' expected '" << stat_property_expected << "'";\
            CPPUNIT_FAIL(error.str().c_str());\
        } \
    } catch(const std::exception& exc){ \
        CPPUNIT_FAIL(exc.what()); \
    } catch(...){ \
        CPPUNIT_FAIL("Got Unknown Error"); \
    }

// use this version to compare different types (bool, unsigned int)
#define SRMCOPY_FILEARGS_TO_SRMCOPYSTAT_D(args_property,args_property_value,stat_property,stat_property_expected) \
    _SRMCOPY_FILEARGS_TO_SRMCOPYSTAT(args_property,args_property_value,stat_property,stat_property_expected,compare)

// use this version to compare strings
#define SRMCOPY_FILEARGS_TO_SRMCOPYSTAT_S(args_property,stat_property,value) \
    _SRMCOPY_FILEARGS_TO_SRMCOPYSTAT(args_property,value,stat_property,value,compare_strings)

// use this version to compare equal types
#define SRMCOPY_FILEARGS_TO_SRMCOPYSTAT_V(args_property,stat_property,value) \
    _SRMCOPY_FILEARGS_TO_SRMCOPYSTAT(args_property,value,stat_property,value,compare)


void TransferStructsTestCase::srmcopy_args_to_srmcopystat(){
    __TIMER;
    // SrmCopy does not foresee a source space token, but check it's copied anyway
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_S(source_space_token,   mm_common.mm_source_space_token,  "token");
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_S(source_token_descr,   mm_common.mm_source_token_descr,  "token_descr");
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_S(dest_space_token,     mm_common.mm_dest_space_token,    "token");
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_S(dest_token_descr,     mm_common.mm_dest_token_descr,    "token_descr");

    SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(enable_dir_check,false,mm_common.mm_enable_dir_check,0);
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(enable_dir_check,true,mm_common.mm_enable_dir_check,1);

    SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(enable_ping_source,false,mm_common.mm_enable_ping_source,0);
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(enable_ping_source,true,mm_common.mm_enable_ping_source,1);

    SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(enable_ping_dest,false,mm_common.mm_enable_ping_dest,0);
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(enable_ping_dest,true,mm_common.mm_enable_ping_dest,1);

}

void TransferStructsTestCase::srmcopy_args_to_srmcopystat_330(){
    __TIMER;
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_V(copy_pin_lifetime,mm_common.mm_copy_pin_lifetime,1250);
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(lan_connection,false,mm_common.mm_lan_connection,0);
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(lan_connection,true,mm_common.mm_lan_connection,1);
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(fail_nearline_files,false,mm_common.mm_fail_nearline_files,0);
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_D(fail_nearline_files,true,mm_common.mm_fail_nearline_files,1);
}

void TransferStructsTestCase::srmcopy_args_to_srmcopystat_340(){
    __TIMER;
    SRMCOPY_ARGS_TO_SRMCOPYSTAT_V(tx_to_per_mb,mm_srmcopy.mm_tx_to_per_mb,5.55);
}

void TransferStructsTestCase::srmcopy_args_to_srmcopystat_350(){
    __TIMER;
    SRMCOPY_FILEARGS_TO_SRMCOPYSTAT_S(source,                   mm_src_name,                "srm://foo:1234/srm/managerv2?SFN=/bar");
    SRMCOPY_FILEARGS_TO_SRMCOPYSTAT_S(destination,              mm_dest_name,               "srm://bar:4321/srm/managerv2?SFN=/foo");
    SRMCOPY_FILEARGS_TO_SRMCOPYSTAT_D(compare_checksum,false,   mm_compare_checksum,        0);
    SRMCOPY_FILEARGS_TO_SRMCOPYSTAT_D(compare_checksum,true,    mm_compare_checksum,        1);
    SRMCOPY_FILEARGS_TO_SRMCOPYSTAT_S(checksum_algorithm,  mm_checksum_user_algorithm, "FOOBAR32");
    SRMCOPY_FILEARGS_TO_SRMCOPYSTAT_S(checksum_value,      mm_checksum_user_value,     "c0ffee"); // an hex string
}
