/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Test classes for Savannag bug #37018.
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: UrlCopyBug_37018.h,v 1.1 2009/03/19 13:37:09 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#ifndef TEST_URLCOPYBUG_37018_H_
#define TEST_URLCOPYBUG_37018_H_

#include "test-utility.h"
#include "UrlCopyCoreTestCase_Common.h"

/**
 * Bug #37018 for UrlCopy transfers
 */
class UrlCopyBug_37018 :
    public UrlCopyCoreTestCase_Common,
    public CppUnit::TestCase{
private:

    void bug_setup(
        const char * test_name,
        const char * source_file,
        const char * dest_file,
        int fail_nearline_files);

    // tests
    CPPUNIT_TEST_SUITE( UrlCopyBug_37018 );
        CPPUNIT_TEST( online_01 );
        CPPUNIT_TEST( online_02 );
        CPPUNIT_TEST( nearline_01 );
        CPPUNIT_TEST( nearline_02 );
    CPPUNIT_TEST_SUITE_END();

    /**
     * Test that online files always succeed
     */
    void online_01();

    /**
     * Test that online files always succeed
     */
    void online_02();

    /**
     * Test that nearline files fail if the "fail nearline files" option is specified
     */
    void nearline_01();

    /**
     * Test that nearline files succeed if the "fail nearline files" option is not specified
     */
    void nearline_02();
};

#endif // TEST_URLCOPYBUG_37018_H_
