/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Test case for Savannah bug #47879: transfer-url-copy tries a preparToGet for directory
 *
 *  Authors: Zsolt Molnar <Zsolt.Molnar@cern.ch>
 *  Version info: $Id: UrlCopyBug_47879.cpp,v 1.1 2009/03/19 13:55:56 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#include "UrlCopyBug_47879.h"
#include "Mmap.h"
#include "UrlCopyCore.h"
#include "stat-utility.h"

using namespace glite::data::transfer::urlcopy;

// SRM endpoints
extern std::string g_srm_11_endpoint;
extern std::string g_srm_22_endpoint;

namespace{
    const char SAMPLE_TEXT[] = "All work and no play makes Jack a dull boy.";
}

void UrlCopyBug_47879::test()
{
	time_t current;
	time(&current);

	static const char * test_name   = "UrlCopyBug_47879";
	static const char * source_file = "testdir/testfile";
	static const char * source_dir = "testdir";
	static const char * dest_file   = "dest_online_01.dat";

	putFile(source_file,g_srm_22_endpoint,"2.2",SAMPLE_TEXT);
	statSetUp(test_name,source_dir,g_srm_22_endpoint,"2.2",dest_file,g_srm_22_endpoint,"2.2", true);

	UrlCopyCore tx(test_name);
	tx.prepare();

	// Get the stat object
	boost::shared_ptr<Mmap> mmap_ptr = open_stat(test_name,true);
	UrlCopyStat * stat = reinterpret_cast<UrlCopyStat *>(mmap_ptr->buffer());
	CPPUNIT_ASSERT_MESSAGE("Invalid stat"   , stat != 0);
	CPPUNIT_ASSERT_MESSAGE("Invalid stat ID", stat->mm_common.mm_id == URLCOPY_STAT_ID);
	// Check Status. Must stay in PREPARING
	check_scope("Invalid Scope", stat->mm_urlcopy.mm_error.mm_scope, UrlCopyError::SCOPE_SOURCE);
	check_phase("Invalid Phase", stat->mm_urlcopy.mm_error.mm_phase, UrlCopyError::PHASE_PREPARATION);
	check_status("Invalid Status (prepare)", stat->mm_urlcopy.mm_status, UrlCopyStatus::PREPARING);
	check_category("Invalid Error (prepare)" , stat->mm_urlcopy.mm_error.mm_category, UrlCopyError::ERROR_USER);
}
