/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: UrlCopyCoreTokens Test Case
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: UrlCopyCoreCheckSumTestCase.h,v 1.3 2009/10/26 16:32:20 molnarzs Exp $
 *  Release: $Name:  $
 *
 */

#ifndef TEST_URLCOPYCORECHECKSUMTESTCASE_H_
#define TEST_URLCOPYCORECHECKSUMTESTCASE_H_

#include "test-utility.h"
#include "UrlCopyCoreTestCase_Common.h"

/**
 * CPPUnit TestCase
 */
class UrlCopyCoreCheckSumTestCase :
    public UrlCopyCoreTestCase_Common,
    public CppUnit::TestCase{
private:
    // Declare CPPUnit Methods
    // -------------------------------------------------------------------------
    CPPUNIT_TEST_SUITE( UrlCopyCoreCheckSumTestCase );
        CPPUNIT_TEST(test_setup);
        
        CPPUNIT_TEST(testUseCase0);

        CPPUNIT_TEST(testUseCase1_src_dst_checksumMatch);
        CPPUNIT_TEST(testUseCase1_src_checksumNotAvailable);
        CPPUNIT_TEST(testUseCase1_src_checksumDifferent);
        CPPUNIT_TEST(testUseCase1_dst_gridFTPfallback);
        CPPUNIT_TEST(testUseCase1_dst_checksumNotAvailable);
        CPPUNIT_TEST(testUseCase1_dst_checksumDifferent);

        CPPUNIT_TEST(testUseCase2_src_dst_checksumMatch);
        CPPUNIT_TEST(testUseCase2_src_checksumNotAvailable_gridFTP);
        CPPUNIT_TEST(testUseCase2_src_checksumNotAvailable);
        CPPUNIT_TEST(testUseCase2_dst_checksumNotAvailable_gridFTP);
        CPPUNIT_TEST(testUseCase2_dst_checksumNotAvailable);
        CPPUNIT_TEST(testUseCase2_checksumDifferent);

        CPPUNIT_TEST(testUseCase3_src_dst_checksumMatch);
        CPPUNIT_TEST(testUseCase3_src_checksumNotAvailable_gridFTP);
        CPPUNIT_TEST(testUseCase3_src_checksumNotAvailable);
        CPPUNIT_TEST(testUseCase3_src_checksumDifferent);
        CPPUNIT_TEST(testUseCase3_dst_checksumNotAvailable_gridFTP);
        CPPUNIT_TEST(testUseCase3_dst_checksumNotAvailable);
        CPPUNIT_TEST(testUseCase3_dst_checksumDifferent);

        CPPUNIT_TEST(testMismatchInAlgorithmName);
        CPPUNIT_TEST(testNonStandardAlgorithmName);
        CPPUNIT_TEST(testUseCase1_src_dst_deviated_checksumMatch);
        CPPUNIT_TEST(testChecksumSpecDeviations);
        CPPUNIT_TEST(testChecksumCaseIndependence);
        CPPUNIT_TEST(testChecksum);

    CPPUNIT_TEST_SUITE_END();

    /**
     * tests for checksum options handling
     */
    void test_setup();

    /**
     * User does not provide checksum, comparison not required.
     */
    void testUseCase0();

    /**
     * Use case 1
     * Source/destination checksum is available from SrmLs and matches.
     */
    void testUseCase1_src_dst_checksumMatch();

    /**
     * Use case 1
     * Source checksum is not available from SrmLs - do not fall back to gridFTP
     */
    void testUseCase1_src_checksumNotAvailable();

    /**
     * Use case 1
     * Source checksum is available, but different. The test retrieves it from the SrmLs, no
     * explicit test for wrong checksum returned from gridFTP (the comparison code to be tested
     * is shared).
     */
    void testUseCase1_src_checksumDifferent();

    /**
     * Use case 1
     * Source checksum is OK, destination checksum is not available from srmLs, fallback to gridftp.
     */
    void testUseCase1_dst_gridFTPfallback();

    /**
     * Use case 1
     * Source checksum is OK, destination checksum is not available. Should be CHECKSUM_MISMATCH
     * error in the FINALIZATION/DESTINATION.
     */
    void testUseCase1_dst_checksumNotAvailable();

    /**
     * Use case 1
	 * Destination checksum different
     */
    void testUseCase1_dst_checksumDifferent();

    /**
     * Use case 2
     * Source/destination checksum is available from SrmLs and matches.
     */
    void testUseCase2_src_dst_checksumMatch();

    /**
     * Use case 2
     * Source checksum is not available from SrmLs - fall back to gridFTP, checksum is available from
     * there and match
     */
    void testUseCase2_src_checksumNotAvailable_gridFTP();

    /**
     * Use case 2
     * Source checksum is not available at all.
     */
    void testUseCase2_src_checksumNotAvailable();

    /**
     * Use case 2
     * Destination checksum is not available from SrmLs - fall back to gridFTP, checksum is available from
     * there and match
     */
    void testUseCase2_dst_checksumNotAvailable_gridFTP();

    /**
     * Use case 2
     * Source checksum is OK, destination checksum is not available at all.
     */
    void testUseCase2_dst_checksumNotAvailable();

    /**
     * Use case 2
	 * Source/destination checksums are different
     */
    void testUseCase2_checksumDifferent();

    /**
     * Use case 3
     * Source/destination checksum is available from SrmLs and matches with the user value
     */
    void testUseCase3_src_dst_checksumMatch();

    /**
     * Use case 3
     * Source checksum is not available from SrmLs - fall back to gridFTP, checksum is available from
     * there and match
     */
    void testUseCase3_src_checksumNotAvailable_gridFTP();

    /**
     * Use case 3
     * Source checksum is not available at all.
     */
    void testUseCase3_src_checksumNotAvailable();

    /**
     * Use case 3
     * Source checksum is available, but differs from the user value. The test retrieves it from the SrmLs, no
     * explicit test for wrong checksum returned from gridFTP (the comparison code to be tested
     * is shared).
     */
    void testUseCase3_src_checksumDifferent();

    /**
     * Use case 3
     * Destination checksum is not available from SrmLs - fall back to gridFTP, checksum is available from
     * there and match
     */
    void testUseCase3_dst_checksumNotAvailable_gridFTP();

    /**
     * Use case 3
     * Source checksum is OK, destination checksum is not available at all.
     */
    void testUseCase3_dst_checksumNotAvailable();

    /**
     * Use case 3
	 * Source/destination checksums are different
     */
    void testUseCase3_dst_checksumDifferent();

    /**
	 * Check if the comparison fails in case of algorithm name mismatch
     */
    void testMismatchInAlgorithmName();

    /**
     * Check if the code takes care of a non-standard (but temporarily valid) algorithm name.
     */
    void testNonStandardAlgorithmName();

    /**
     * See: https://savannah.cern.ch/bugs/?57046
     * There are deviations from the checksum format specifications. Test those.
     */
    void testChecksumSpecDeviations();

    /**
     * See: https://savannah.cern.ch/bugs/index.php?66507
     * Thecksum comparison must be case independent.
     */
    void testChecksumCaseIndependence();

    /**
     * Test checksum match with deviated checksum value
     */
    void testUseCase1_src_dst_deviated_checksumMatch();

    /** Test Checksum methods */
    void testChecksum();
};

#endif // TEST_URLCOPYCORECHECKSUMTESTCASE_H_
