/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: UrlCopyCore Test Case
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: UrlCopyCoreTestCase.h,v 1.2 2009/07/30 19:32:55 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#ifndef TEST_URLCOPYCORETESTCASE_H_
#define TEST_URLCOPYCORETESTCASE_H_

#include "test-utility.h"
#include "UrlCopyCoreTestCase_Common.h"

/**
 * CPPUnit TestCase
 */
class UrlCopyCoreTestCase :
    public UrlCopyCoreTestCase_Common,
    public CppUnit::TestCase{
private:
    // Declare CPPUnit Methods
    // -------------------------------------------------------------------------
    CPPUNIT_TEST_SUITE( UrlCopyCoreTestCase );
        // 1.1 Test
        CPPUNIT_TEST( test_PutSource_11 );
        CPPUNIT_TEST( test_SetUp_11 );
        CPPUNIT_TEST( testPrepare_11 );
        CPPUNIT_TEST( testTransfer_11 );
        CPPUNIT_TEST( testComplete_11 );
        // 2.2 Test
        CPPUNIT_TEST( test_PutSource_22 );
        CPPUNIT_TEST( test_SetUp_22 );
        CPPUNIT_TEST( testPrepare_22 );
        CPPUNIT_TEST( testTransfer_22 );
        CPPUNIT_TEST( testComplete_22 );
        // 1.1 & 2.2 Test
        CPPUNIT_TEST( test_PutSource_11_22 );
        CPPUNIT_TEST( test_SetUp_11_22 );
        CPPUNIT_TEST( testPrepare_11_22 );
        CPPUNIT_TEST( testTransfer_11_22 );
        CPPUNIT_TEST( testComplete_11_22 );
        // 2.2 & 1.1 Test
        CPPUNIT_TEST( test_PutSource_22_11 );
        CPPUNIT_TEST( test_SetUp_22_11 );
        CPPUNIT_TEST( testPrepare_22_11 );
        CPPUNIT_TEST( testTransfer_22_11 );
        CPPUNIT_TEST( testComplete_22_11 );
        // specific cases
        CPPUNIT_TEST( test_0LenPtg_11 );
        CPPUNIT_TEST( test_0LenPtg_22 );
        CPPUNIT_TEST( test_0Len_11 );
        CPPUNIT_TEST( test_0Len_22 );
        CPPUNIT_TEST( test_MkDir_Duplication );
        CPPUNIT_TEST( test_SetFileStatusFailure_11 );
    CPPUNIT_TEST_SUITE_END();

    // Test Methods
    // -------------------------------------------------------------------------

    /**
     * Test Setup for SRM 1.1
     */
    void test_PutSource_11();
    void test_PutSource_22();
    void test_PutSource_11_22();
    void test_PutSource_22_11();
    void test_SetUp_11();
    void test_SetUp_22();
    void test_SetUp_11_22();
    void test_SetUp_22_11();

    /**
     * Test Prepare Method
     */
    void testPrepare_11();
    void testPrepare_22();
    void testPrepare_11_22();
    void testPrepare_22_11();

    /**
     * Test Transfer Method
     */
    void testTransfer_11();
    void testTransfer_22();
    void testTransfer_11_22();
    void testTransfer_22_11();

    /**
     * Test Complete Method
     */
    void testComplete_11();
    void testComplete_22();
    void testComplete_11_22();
    void testComplete_22_11();

    /**
     * test case of source SRM returning 0 length in prepareToGet.
     * Verify that srmLs is attempted.
     */
    void test_0LenPtg_11();
    void test_0LenPtg_22();

    /**
     * test case of source file actually having 0 length (file lost).
     * Verify that transfer is not started
     */
    void test_0Len_11();
    void test_0Len_22();

    /**
     * Verify that the transfer succeeds if a directory does not exist on stat
     * but exists on mkdir (happening e.g. if another transfer created the
     * directory in the meanwhile)
     */
    void test_MkDir_Duplication();

    /**
     * first set file status request failing
     */
    void test_SetFileStatusFailure_11();

protected:

    /**
     * call prepare and check expected results for 0 length test file
     */
    void prepare0Len(const std::string& test_name);

};

#endif // TEST_URLCOPYCORETESTCASE_H_
