/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: UrlCopyCore Test Case
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: UrlCopyCoreTestCase_Common.h,v 1.5 2009/07/30 19:32:55 molnarzs Exp $
 *  Release: $Name:  $
 *
 */

#ifndef TEST_URLCOPYCORETESTCASE_COMMON_H_
#define TEST_URLCOPYCORETESTCASE_COMMON_H_

#include <string>

class UrlCopyCoreTestCase_Common {
protected:

    /**
     * Setup stat file for the tests
     */
    void statSetUp(
        const std::string&  name,
        const std::string&  src_name,
        const std::string&  src_endpoint,
        const std::string&  src_version,
        const std::string&  dst_name,
        const std::string&  dst_endpoint,
        const std::string&  dst_version,
        const bool          isSrcADir = false);

    /**
     * stat setup with parameters for space tokens
     */
    void statSetUpWithTokens(
        const std::string&  name,
        const std::string&  src_name,
        const std::string&  src_endpoint,
        const std::string&  src_version,
        const std::string&  dst_name,
        const std::string&  dst_endpoint,
        const std::string&  dst_version,
        const std::string&  src_token_description,
        const std::string&  dst_token_description);

    /**
     * stat setup with parameters for addendum to WLCG user agreement
     */
    void statSetUpWlcg(
        const std::string&  name,
        const std::string&  src_name,
        const std::string&  src_endpoint,
        const std::string&  src_version,
        const std::string&  dst_name,
        const std::string&  dst_endpoint,
        const std::string&  dst_version,
        int                 copy_pin_lifetime,
        int                 lan_connection,
        int                 fail_nearline_files);

    /**
     * stat setup with checksum parameters
     */
    void statSetUpChecksum(
        const std::string&  name,
        const std::string&  src_name,
        const std::string&  src_endpoint,
        const std::string&  src_version,
        const std::string&  dst_name,
        const std::string&  dst_endpoint,
        const std::string&  dst_version,
        const std::string&  user_algorithm,
        const std::string&  user_value,
        const bool compare);

    /**
     * Call prepare
     */
    void prepare(const std::string& name);
    /**
     * Call transfer
     */
    void transfer(const std::string& name);
    /**
     * Call complete
     */
    void complete(const std::string& name);

};

#endif

