/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Transfer Url Copy: Mmap Test Case
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: UtilitiesTestCase.h,v 1.1 2009/03/19 13:37:09 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#ifndef TEST_UTILITIESTESTCASE_H_
#define TEST_UTILITIESTESTCASE_H_

#include "test-utility.h"

/**
 * Utilities TestCase
 */
class UtilitiesTestCase : public CppUnit::TestCase{
public:
    /**
     * test case setup
     */
    void setUp ();
    /**
     * test case teardown
     */
    void tearDown ();

private:
    // Declare CPPUnit Methods
    // -------------------------------------------------------------------------
    CPPUNIT_TEST_SUITE( UtilitiesTestCase );
        CPPUNIT_TEST( test_check_cmdline_file_match );
        CPPUNIT_TEST( test_check_cmdline_file_missing_file );
        CPPUNIT_TEST( test_check_cmdline_file_different_exec_name );
        CPPUNIT_TEST( test_check_cmdline_file_different_tx_id );
    CPPUNIT_TEST_SUITE_END();

    // Test Methods
    // -------------------------------------------------------------------------

    /**
     * matching exec name and tx id
     */
    void test_check_cmdline_file_match();
    /**
     * missing file
     */
    void test_check_cmdline_file_missing_file();
    /**
     * different exec name
     */
    void test_check_cmdline_file_different_exec_name();
    /**
     * different tx id
     */
    void test_check_cmdline_file_different_tx_id();

private:

    void write_cmd_line_param(std::ofstream& stream,const std::string& line);

    // an existing (temp) file
    std::string test_file;
    // a non-existing (temp) file
    std::string test_file_nonexisting;

    // constants
    static const std::string ExecName;
    static const std::string TxId;

};

#endif // TEST_UTILITIESTESTCASE_H_
