#!/bin/bash 
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#-------------------------------------------------------------------------------
# Unit tests for org.glite.data.transfer-url-copy
# Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
# Version info: $Id: unit-test.sh,v 1.6 2009/12/03 17:21:45 molnarzs Exp $
# Release: $Name:  $
#-------------------------------------------------------------------------------

# check if the WORKSPACE environment variable is defined
if [ -z "${WORKSPACE}" ]; then
    echo "The WORKSPACE environment variable is not set."
    exit 1
fi

test_utils_module="org.glite.data.test-utils"
test_utils_dir="${WORKSPACE}/${test_utils_module}"

# source the test-common script
test_common_script="${test_utils_dir}/test-common.sh"
if [ ! -e ${test_common_script} ]; then
    echo "Checkout or update the ${test_utils_module} module."
    exit 1
fi
. ${test_common_script}

# source the test-proxy-utils script
test_proxy_utils_script="${test_utils_dir}/test-proxy-utils.sh"
if [ ! -e ${test_proxy_utils_script} ]; then
    echo "Checkout or update the ${test_utils_module} module."
    exit 1
fi
. ${test_proxy_utils_script}

#-------------------------------------------------------------------------------

MODULE_NAME="glite-data-transfer-url-copy"
MODULE_DIR="${WORKSPACE}/org.glite.data.transfer-url-copy"
MODULE_TEST_DIR="${GLITE_LOCATION}/share/test/${MODULE_NAME}"
MODULE_CONFIG_DIR="${GLITE_LOCATION}/share/config/${MODULE_NAME}"
MODULE_CONFIG_TEMPLATES="${MODULE_CONFIG_DIR}/config-templates"

SRM_UTIL_CPP_NAME="glite-data-srm-util-cpp"
SRM_UTIL_CPP_DIR="${WORKSPACE}/org.glite.data.srm-util-cpp"
SRM_UTIL_CPP_LOCATION="${GLITE_LOCATION}/share/test/${SRM_UTIL_CPP_NAME}"

addpath LD_LIBRARY_PATH ${SRM_UTIL_CPP_LOCATION}/lib

# pool location for stub SRMs
POOL_LOCATION=${MODULE_TEST_DIR}/var/tmp/srm/pool

# initialize tests
function init_unit_test(){
    add_gsoap_paths
    add_globus_paths
    add_log4cpp_paths
    add_glite_paths
    mkdir -p ${MODULE_TEST_DIR}/{etc,config,bin,var/{log,tmp}} || return 1
    cp -v "${SRM_UTIL_CPP_DIR}/config/glite-data-srm-util-cpp.patterns.xml" "${MODULE_TEST_DIR}/etc" || return 1
    cp -v "${MODULE_DIR}/config/glite-data-transfer-url-copy.patterns.xml" "${MODULE_TEST_DIR}/etc" || return 1

    # create certificates
    create_fake_certificates || return 1
    # initialize proxy
    grid_proxy_init || return 1
}

# Install SD stub 
test_transfer_urlcopy_stub_sd_install__DEPENDS="init_unit_test"
function test_transfer_urlcopy_stub_sd_install(){
    # Create services.xml
    cat > ${MODULE_TEST_DIR}/etc/services.xml << EOD
<services>
  <service name="STUB_1_1_SRM">
    <parameters>
      <endpoint>httpg://localhost:8043/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>CERN</site>
    </parameters>
  </service>
  <service name="STUB_2_2_SRM">
    <parameters>
      <endpoint>httpg://localhost:8044/srm/managerv2</endpoint>
      <type>SRM</type>
      <version>2.2</version>
      <site>CERN</site>
    </parameters>
  </service>
</services>
EOD
}
    
# Create configuration for SRM 1.1 Server Stub
test_transfer_urlcopy_stub_server_1_1_install__DEPENDS="init_unit_test"
function test_transfer_urlcopy_stub_server_1_1_install(){
    # Create Template for the SRM 1.1 Stub
    create_config_xml "glite-srm-util-stub-server-1_1" "${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-1.1.config.xml" \
        "${SRM_UTIL_CPP_LOCATION}/config/srm-util-stub-server-1.1.config-template.xml"
    # Create configuration for srm1.1 stub
    config_generator -f ${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-1.1.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-1.1.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-1.1.log-properties \
        -O srm-util-stub-server-1_1.Port=8043 \
        -O srm-util-stub-server-1_1.SecureProtocol=gsi \
        -O srm-util-stub-server-1_1.PoolLocation=${POOL_LOCATION} \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-1.1.log \
        -O log.Priority=DEBUG
}

# Create configuration for SRM 2.2 Server Stub
test_transfer_urlcopy_stub_server_2_2_install__DEPENDS="init_unit_test"
function test_transfer_urlcopy_stub_server_2_2_install(){
    # Create Template for the SRM 2.2 Stub
    create_config_xml "glite-srm-util-stub-server-2_2" "${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-2.2.config.xml" \
        "${SRM_UTIL_CPP_LOCATION}/config/srm-util-stub-server-2.2.config-template.xml"
    # Create configuration for srm2.2 stub
    config_generator -f ${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-2.2.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-2.2.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-2.2.log-properties \
        -O srm-util-stub-server-2_2.Port=8044 \
        -O srm-util-stub-server-2_2.SecureProtocol=gsi \
        -O srm-util-stub-server-2_2.PoolLocation=${POOL_LOCATION} \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-2.2.log \
        -O log.Priority=DEBUG
}

# Create configuration for SRM Util Test
test_transfer_urlcopy_install__DEPENDS="init_unit_test"
function test_transfer_urlcopy_install(){
    # create template for the unit test
    cat > ${MODULE_TEST_DIR}/config/glite-transfer-urlcopy-test.config.xml << EOD
<service name="glite-transfer-urlcopy-test">
<components>
<component name="glite-transfer-urlcopy-test">
 <config-template>
  <description>Unit Test for Transfer UrlCopy</description>
    <config>
      <param name="srm11Pool" type="string">
        <description>The stub srm 1.1 pool location</description>
      </param>
      <param name="srm22Pool" type="string">
        <description>The stub srm 2.2 pool location</description>
      </param>
    </config>
 </config-template>
</component>
</components>
</service>
EOD
    # create configuration for the unit test
    config_generator -f ${MODULE_TEST_DIR}/config/glite-transfer-urlcopy-test.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-urlcopy-test.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-urlcopy-test.log-properties \
        -O glite-transfer-urlcopy-test.srm11Pool=${POOL_LOCATION} \
        -O glite-transfer-urlcopy-test.srm22Pool=${POOL_LOCATION} \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-urlcopy-test.log \
        -O log.Priority=DEBUG

}

start_stub_servers__DEPENDS="init_unit_test test_transfer_urlcopy_stub_server_1_1_install test_transfer_urlcopy_stub_server_2_2_install"
function start_stub_servers(){
    # Kill Previous errors 
    killall glite_data_config_service
    sleep 1
    killall glite_data_config_service
    sleep 5
    # Start the SRM 1.1 Stub
    echo "Starting SRM 1.1 Stub..."
    (cd ${GLITE_LOCATION}/bin && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        CGSI_TRACE=${TESTS_CGSI_TRACE} \
        CGSI_TRACEFILE="${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-1.1.cgsi" \
        ${GLITE_LOCATION}/bin/glite_data_config_service -v glite-srm-util-stub-server-1.1 start) || return ${?}
    #config_service glite-srm-util-stub-server-1.1 start || return ${?}
    echo "SRM 1.1 Stub Started"
    # start SRM2.2 stub
    echo "Starting SRM 2.2 Stub..."
    (cd ${GLITE_LOCATION}/bin && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        CGSI_TRACE=${TESTS_CGSI_TRACE} \
        CGSI_TRACEFILE="${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-2.2.cgsi" \
        ${GLITE_LOCATION}/bin/glite_data_config_service -v glite-srm-util-stub-server-2.2 start) || return ${?}
    echo "SRM 2.2 Stub Started"
    return 0

}

stop_stub_servers__DEPENDS="init_unit_test"
function stop_stub_servers(){
    echo "Stopping SRM 2.2 Stub..."
    config_service glite-srm-util-stub-server-2.2 stop
    echo "SRM 2.2 Stub Stopped."
    echo "Stopping SRM 1.1 Stub..."
    config_service glite-srm-util-stub-server-1.1 stop
    echo "SRM 1.1 Stub Stopped."
}

#-------------------------------------------------------------------------------
#                           Additional test functions
# not part of the suite started by the test_all target
#-------------------------------------------------------------------------------

# create a test file in the SRM pool
function create_test_file(){
    echo "All work and no play makes Jack a dull boy" > ${POOL_LOCATION}/${1}
}

# create the SURL of the file (same path of the SRM pool)
function s(){
    echo "srm://localhost:8044/srm/managerv2?SFN=${1}"
}

# run transfers directly to check for some bugs
utils_tests__DEPENDS="init_unit_test start_stub_servers"
function utils_tests(){
    # add libexec path
    addpath PATH ${GLITE_LOCATION}/libexec

    # test a ping
    glite-srm-util-ping -I 2.2 -s httpg://localhost:8044/srm/managerv2
    
    rm -v ${POOL_LOCATION}/dst{00,01,02,04,05,06}.dat

    create_test_file "src00.dat"
    create_test_file "src01.dat"
    create_test_file "src02.dat"
    create_test_file "this-one-returns-SRM_DUPLICATION_ERROR-on-copy.dat"
    create_test_file "src04.dat"
    create_test_file "src05.dat"
    create_test_file "src06.dat"
    
    CMD="glite-srm-copy -b -C -d --copy-pin-lifetime 100 \
        $(s src00.dat) $(s dst00.dat) \
        $(s src01.dat) $(s dst01.dat) \
        $(s src02.dat) $(s dst02.dat) \
        $(s this-one-returns-SRM_DUPLICATION_ERROR-on-copy.dat) $(s dst03.dat) \
        $(s src04.dat) $(s dst04.dat) \
        $(s src05.dat) $(s dst05.dat) \
        $(s src06.dat) $(s dst06.dat)"

    echo $CMD
    $CMD

    # stop the stub servers
    run_test_function stop_stub_servers
}

#-------------------------------------------------------------------------------

function show_test_help(){
    cat << EOD

Environment variables:
 TEST_CLASSES : list of named test classes to execute (unset to execute all)
    run ${MODULE_TEST_DIR}/bin/glite-data-transfer-urlcopy-test -h
    to get the list of possible test classes
 USE_GDB : if set, run test program inside gdb
 PRINT_TEST_TIMES : if set, print the timing of each test method
EOD
}

